Class: PostForMe::Models::AccountConfiguration::Configuration::Localization

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/post_for_me/models/account_configuration.rb,
sig/post_for_me/models/account_configuration.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(localizations:, allow_comment: nil, allow_duet: nil, allow_stitch: nil, audio_name: nil, auto_add_music: nil, board_ids: nil, caption: nil, category_id: nil, collaborators: nil, community_id: nil, contains_synthetic_media: nil, default_language: nil, disclose_branded_content: nil, disclose_your_brand: nil, embeddable: nil, is_ai_generated: nil, is_draft: nil, license: nil, link: nil, location: nil, made_for_kids: nil, media: nil, placement: nil, poll: nil, privacy_status: nil, public_stats_viewable: nil, publish_at: nil, quote_tweet_id: nil, recording_date: nil, reply_settings: nil, reshare_post_id: nil, set_caption_for_each_image: nil, share_to_feed: nil, tags: nil, title: nil, trial_reel_type: nil) ⇒ Localization

Some parameter documentations has been truncated, see PostForMe::Models::AccountConfiguration::Configuration for more details.

Configuration for the social account

Parameters:

  • localizations (Hash{Symbol=>PostForMe::Models::AccountConfiguration::Configuration::Localization}, nil)

    Per-language localizations for the video title and description. Keys are BCP-47

  • allow_comment (Boolean, nil) (defaults to: nil)

    Allow comments on TikTok

  • allow_duet (Boolean, nil) (defaults to: nil)

    Allow duets on TikTok

  • allow_stitch (Boolean, nil) (defaults to: nil)

    Allow stitch on TikTok

  • audio_name (String, nil) (defaults to: nil)

    Display name for the audio track on Instagram Reels. Only honored on Reels uploa

  • auto_add_music (Boolean, nil) (defaults to: nil)

    Will automatically add music to photo posts on TikTok

  • board_ids (Array<String>, nil) (defaults to: nil)

    Pinterest board IDs

  • caption (Object, nil) (defaults to: nil)

    Overrides the caption from the post

  • category_id (String, nil) (defaults to: nil)

    YouTube video category id (maps to snippet.categoryId; see YouTube Data API vide

  • collaborators (Array<Array<Object>>, nil) (defaults to: nil)

    List of page ids or users to invite as collaborators for a Video Reel (Instagram

  • community_id (String) (defaults to: nil)

    Id of the twitter community to post to

  • contains_synthetic_media (Boolean, nil) (defaults to: nil)

    If true, marks the YouTube video as containing altered or synthetic content per

  • default_language (String, nil) (defaults to: nil)

    Default language of the video (BCP-47 language tag, e.g. "en"). Maps to snippet.

  • disclose_branded_content (Boolean, nil) (defaults to: nil)

    Disclose branded content on TikTok

  • disclose_your_brand (Boolean, nil) (defaults to: nil)

    Disclose your brand on TikTok

  • embeddable (Boolean, nil) (defaults to: nil)

    If true the video can be embedded on other websites (maps to status.embeddable).

  • is_ai_generated (Boolean, nil) (defaults to: nil)

    Flag content as AI generated on TikTok

  • is_draft (Boolean, nil) (defaults to: nil)

    Will create a draft upload to TikTok, posting will need to be completed from wit

  • license (Symbol, PostForMe::Models::AccountConfiguration::Configuration::License, nil) (defaults to: nil)

    The video's license (maps to status.license). "youtube" is the standard YouTube

  • link (String, nil) (defaults to: nil)

    Pinterest post link

  • location (String, nil) (defaults to: nil)

    Page id with a location that you want to tag the image or video with (Instagram

  • made_for_kids (Boolean, nil) (defaults to: nil)

    If true will notify YouTube the video is intended for kids, defaults to false

  • media (Array<PostForMe::Models::SocialPostMedia>, nil) (defaults to: nil)

    Overrides the media from the post

  • placement (Symbol, PostForMe::Models::AccountConfiguration::Configuration::Placement, nil) (defaults to: nil)

    Post placement for Facebook/Instagram/Threads

  • poll (PostForMe::Models::TwitterPoll) (defaults to: nil)

    Poll options for the twitter

  • privacy_status (Symbol, PostForMe::Models::AccountConfiguration::Configuration::PrivacyStatus, nil) (defaults to: nil)

    Sets the privacy status for TikTok (private, public), or YouTube (private, publi

  • public_stats_viewable (Boolean, nil) (defaults to: nil)

    If true, the extended video statistics are publicly viewable (maps to status.pub

  • publish_at (String, nil) (defaults to: nil)

    ISO 8601 datetime at which the video should be published. Only honoured when pri

  • quote_tweet_id (String) (defaults to: nil)

    Id of the tweet you want to quote

  • recording_date (String, nil) (defaults to: nil)

    ISO 8601 date (YYYY-MM-DD) or datetime when the video was recorded (maps to reco

  • reply_settings (Symbol, PostForMe::Models::AccountConfiguration::Configuration::ReplySettings, nil) (defaults to: nil)

    Who can reply to the tweet

  • reshare_post_id (String, nil) (defaults to: nil)

    LinkedIn UGC post id to reshare. The caption is used as the reshare commentary.

  • set_caption_for_each_image (Boolean, nil) (defaults to: nil)

    If true, include the caption on each image in a Facebook carousel upload; if fal

  • share_to_feed (Boolean, nil) (defaults to: nil)

    If false Instagram video posts will only be shown in the Reels tab

  • tags (Array<String>, nil) (defaults to: nil)

    YouTube video tags

  • title (String, nil) (defaults to: nil)

    Overrides the title from the post (Pinterest, TikTok, YouTube)

  • trial_reel_type (Symbol, PostForMe::Models::AccountConfiguration::Configuration::TrialReelType, nil) (defaults to: nil)

    Instagram trial reel type, when passed will be created as a trial reel. If manua

  • description: (String, nil)
  • title: (String, nil) (defaults to: nil)


364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
# File 'lib/post_for_me/models/account_configuration.rb', line 364

class Localization < PostForMe::Internal::Type::BaseModel
  # @!attribute description
  #
  #   @return [String, nil]
  optional :description, String, nil?: true

  # @!attribute title
  #
  #   @return [String, nil]
  optional :title, String, nil?: true

  # @!method initialize(description: nil, title: nil)
  #   @param description [String, nil]
  #   @param title [String, nil]
end

Instance Attribute Details

#descriptionString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


368
# File 'lib/post_for_me/models/account_configuration.rb', line 368

optional :description, String, nil?: true

#titleString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


373
# File 'lib/post_for_me/models/account_configuration.rb', line 373

optional :title, String, nil?: true

Instance Method Details

#to_hash{ description: String?, title: String? }

Returns:

  • ({ description: String?, title: String? })


235
# File 'sig/post_for_me/models/account_configuration.rbs', line 235

def to_hash: -> { description: String?, title: String? }