Class: PostForMe::Models::CreateSocialPost

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/post_for_me/models/create_social_post.rb,
sig/post_for_me/models/create_social_post.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(caption:, social_accounts:, account_configurations: nil, external_id: nil, is_draft: nil, media: nil, platform_configurations: nil, scheduled_at: nil) ⇒ Object

Some parameter documentations has been truncated, see PostForMe::Models::CreateSocialPost for more details.

Parameters:

  • caption (String)

    Caption text for the post

  • social_accounts (Array<String>)

    Array of social account IDs for posting

  • account_configurations (Array<PostForMe::Models::AccountConfiguration>, nil) (defaults to: nil)

    Account-specific configurations for the post

  • external_id (String, nil) (defaults to: nil)

    Array of social account IDs for posting

  • is_draft (Boolean, nil) (defaults to: nil)

    If isDraft is set then the post will not be processed

  • media (Array<PostForMe::Models::SocialPostMedia>, nil) (defaults to: nil)

    Array of media associated with the post. If multiple media items are provided an

  • platform_configurations (PostForMe::Models::PlatformConfigurationsDto, nil) (defaults to: nil)

    Platform-specific configurations for the post

  • scheduled_at (Time, nil) (defaults to: nil)

    Scheduled date and time for the post, setting to null or undefined will post ins



# File 'lib/post_for_me/models/create_social_post.rb', line 58

Instance Attribute Details

#account_configurationsArray<PostForMe::Models::AccountConfiguration>?

Account-specific configurations for the post

Parameters:

Returns:



22
23
24
# File 'lib/post_for_me/models/create_social_post.rb', line 22

optional :account_configurations,
-> { PostForMe::Internal::Type::ArrayOf[PostForMe::AccountConfiguration] },
nil?: true

#captionString

Caption text for the post

Parameters:

  • value (String)

Returns:

  • (String)


10
# File 'lib/post_for_me/models/create_social_post.rb', line 10

required :caption, String

#external_idString?

Array of social account IDs for posting

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


30
# File 'lib/post_for_me/models/create_social_post.rb', line 30

optional :external_id, String, nil?: true

#is_draftBoolean?

If isDraft is set then the post will not be processed

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


36
# File 'lib/post_for_me/models/create_social_post.rb', line 36

optional :is_draft, PostForMe::Internal::Type::Boolean, api_name: :isDraft, nil?: true

#mediaArray<PostForMe::Models::SocialPostMedia>?

Array of media associated with the post. If multiple media items are provided and the placement is stories, individual posts are created per media item.

Parameters:

Returns:



43
# File 'lib/post_for_me/models/create_social_post.rb', line 43

optional :media, -> { PostForMe::Internal::Type::ArrayOf[PostForMe::SocialPostMedia] }, nil?: true

#platform_configurationsPostForMe::Models::PlatformConfigurationsDto?

Platform-specific configurations for the post



49
# File 'lib/post_for_me/models/create_social_post.rb', line 49

optional :platform_configurations, -> { PostForMe::PlatformConfigurationsDto }, nil?: true

#scheduled_atTime?

Scheduled date and time for the post, setting to null or undefined will post instantly

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


56
# File 'lib/post_for_me/models/create_social_post.rb', line 56

optional :scheduled_at, Time, nil?: true

#social_accountsArray<String>

Array of social account IDs for posting

Parameters:

  • value (::Array[String])

Returns:

  • (Array<String>)


16
# File 'lib/post_for_me/models/create_social_post.rb', line 16

required :social_accounts, PostForMe::Internal::Type::ArrayOf[String]

Instance Method Details

#to_hash{

Returns:

  • ({)


43
# File 'sig/post_for_me/models/create_social_post.rbs', line 43

def to_hash: -> {