Class: PostForMe::Models::FacebookConfigurationDto

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/post_for_me/models/facebook_configuration_dto.rb,
sig/post_for_me/models/facebook_configuration_dto.rbs

Defined Under Namespace

Modules: Placement

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(caption: nil, collaborators: nil, location: nil, media: nil, placement: nil, set_caption_for_each_image: nil) ⇒ Object

Some parameter documentations has been truncated, see PostForMe::Models::FacebookConfigurationDto for more details.

Parameters:

  • caption (Object, nil) (defaults to: nil)

    Overrides the caption from the post

  • collaborators (Array<Array<Object>>, nil) (defaults to: nil)

    List of page ids to invite as collaborators for a Video Reel

  • location (String, nil) (defaults to: nil)

    Page id with a location that you want to tag the image or video with

  • media (Array<PostForMe::Models::SocialPostMedia>, nil) (defaults to: nil)

    Overrides the media from the post

  • placement (Symbol, PostForMe::Models::FacebookConfigurationDto::Placement, nil) (defaults to: nil)

    Facebook post placement

  • set_caption_for_each_image (Boolean, nil) (defaults to: nil)

    If true, include the caption on each image in a carousel upload; if false, only



# File 'lib/post_for_me/models/facebook_configuration_dto.rb', line 45

Instance Attribute Details

#captionObject?

Overrides the caption from the post

Parameters:

  • value (top, nil)

Returns:

  • (Object, nil)


10
# File 'lib/post_for_me/models/facebook_configuration_dto.rb', line 10

optional :caption, PostForMe::Internal::Type::Unknown, nil?: true

#collaboratorsArray<Array<Object>>?

List of page ids to invite as collaborators for a Video Reel

Parameters:

  • value (::Array[::Array[top]], nil)

Returns:

  • (Array<Array<Object>>, nil)


16
17
18
# File 'lib/post_for_me/models/facebook_configuration_dto.rb', line 16

optional :collaborators,
PostForMe::Internal::Type::ArrayOf[PostForMe::Internal::Type::ArrayOf[PostForMe::Internal::Type::Unknown]],
nil?: true

#locationString?

Page id with a location that you want to tag the image or video with

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


24
# File 'lib/post_for_me/models/facebook_configuration_dto.rb', line 24

optional :location, String, nil?: true

#mediaArray<PostForMe::Models::SocialPostMedia>?

Overrides the media from the post

Parameters:

Returns:



30
# File 'lib/post_for_me/models/facebook_configuration_dto.rb', line 30

optional :media, -> { PostForMe::Internal::Type::ArrayOf[PostForMe::SocialPostMedia] }, nil?: true

#placementSymbol, ...

Facebook post placement

Parameters:

  • value (PostForMe::Models::FacebookConfigurationDto::placement, nil)

Returns:



36
# File 'lib/post_for_me/models/facebook_configuration_dto.rb', line 36

optional :placement, enum: -> { PostForMe::FacebookConfigurationDto::Placement }, nil?: true

#set_caption_for_each_imageBoolean?

If true, include the caption on each image in a carousel upload; if false, only include it on the final carousel post

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


43
# File 'lib/post_for_me/models/facebook_configuration_dto.rb', line 43

optional :set_caption_for_each_image, PostForMe::Internal::Type::Boolean, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


35
# File 'sig/post_for_me/models/facebook_configuration_dto.rbs', line 35

def to_hash: -> {