Class: PostForMe::Models::InstagramConfigurationDto

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/post_for_me/models/instagram_configuration_dto.rb,
sig/post_for_me/models/instagram_configuration_dto.rbs

Defined Under Namespace

Modules: Placement, TrialReelType

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(audio_name: nil, caption: nil, collaborators: nil, location: nil, media: nil, placement: nil, share_to_feed: nil, trial_reel_type: nil) ⇒ Object

Some parameter documentations has been truncated, see PostForMe::Models::InstagramConfigurationDto for more details.

Parameters:

  • audio_name (String, nil) (defaults to: nil)

    Display name for the audio track on Instagram Reels. Only honored on Reels uploa

  • caption (Object, nil) (defaults to: nil)

    Overrides the caption from the post

  • collaborators (Array<String>, nil) (defaults to: nil)

    Instagram usernames to be tagged as a collaborator

  • location (String, nil) (defaults to: nil)

    Page id with a location that you want to tag the image or video with

  • media (Array<PostForMe::Models::SocialPostMedia>, nil) (defaults to: nil)

    Overrides the media from the post

  • placement (Symbol, PostForMe::Models::InstagramConfigurationDto::Placement, nil) (defaults to: nil)

    Instagram post placement

  • share_to_feed (Boolean, nil) (defaults to: nil)

    If false video posts will only be shown in the Reels tab

  • trial_reel_type (Symbol, PostForMe::Models::InstagramConfigurationDto::TrialReelType, nil) (defaults to: nil)

    Instagram trial reel type, when passed will be created as a trial reel. If manua



# File 'lib/post_for_me/models/instagram_configuration_dto.rb', line 58

Instance Attribute Details

#audio_nameString?

Display name for the audio track on Instagram Reels. Only honored on Reels uploads, and only when the audio is original (Meta silently ignores it on licensed/fingerprinted tracks).

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


12
# File 'lib/post_for_me/models/instagram_configuration_dto.rb', line 12

optional :audio_name, String, nil?: true

#captionObject?

Overrides the caption from the post

Parameters:

  • value (top, nil)

Returns:

  • (Object, nil)


18
# File 'lib/post_for_me/models/instagram_configuration_dto.rb', line 18

optional :caption, PostForMe::Internal::Type::Unknown, nil?: true

#collaboratorsArray<String>?

Instagram usernames to be tagged as a collaborator

Parameters:

  • value (::Array[String], nil)

Returns:

  • (Array<String>, nil)


24
# File 'lib/post_for_me/models/instagram_configuration_dto.rb', line 24

optional :collaborators, PostForMe::Internal::Type::ArrayOf[String], nil?: true

#locationString?

Page id with a location that you want to tag the image or video with

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


30
# File 'lib/post_for_me/models/instagram_configuration_dto.rb', line 30

optional :location, String, nil?: true

#mediaArray<PostForMe::Models::SocialPostMedia>?

Overrides the media from the post

Parameters:

Returns:



36
# File 'lib/post_for_me/models/instagram_configuration_dto.rb', line 36

optional :media, -> { PostForMe::Internal::Type::ArrayOf[PostForMe::SocialPostMedia] }, nil?: true

#placementSymbol, ...

Instagram post placement

Parameters:

  • value (PostForMe::Models::InstagramConfigurationDto::placement, nil)

Returns:



42
# File 'lib/post_for_me/models/instagram_configuration_dto.rb', line 42

optional :placement, enum: -> { PostForMe::InstagramConfigurationDto::Placement }, nil?: true

#share_to_feedBoolean?

If false video posts will only be shown in the Reels tab

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


48
# File 'lib/post_for_me/models/instagram_configuration_dto.rb', line 48

optional :share_to_feed, PostForMe::Internal::Type::Boolean, nil?: true

#trial_reel_typeSymbol, ...

Instagram trial reel type, when passed will be created as a trial reel. If manual the trial reel can be manually graduated in the native app. If perfomance the trial reel will be automatically graduated if the trial reel performs well.

Parameters:

  • value (PostForMe::Models::InstagramConfigurationDto::trial_reel_type, nil)

Returns:



56
# File 'lib/post_for_me/models/instagram_configuration_dto.rb', line 56

optional :trial_reel_type, enum: -> { PostForMe::InstagramConfigurationDto::TrialReelType }, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/post_for_me/models/instagram_configuration_dto.rb', line 88

Instance Method Details

#to_hash{

Returns:

  • ({)


43
# File 'sig/post_for_me/models/instagram_configuration_dto.rbs', line 43

def to_hash: -> {