Class: PostForMe::Models::MediaCreateUploadURLResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/post_for_me/models/media_create_upload_url_response.rb,
sig/post_for_me/models/media_create_upload_url_response.rbs

Overview

See Also:

  • PostForMe::Resources::Media#create_upload_url

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(media_url:, upload_url:) ⇒ MediaCreateUploadURLResponse

Returns a new instance of MediaCreateUploadURLResponse.

Parameters:

  • media_url (String)

    The public URL for the media, to use once file has been uploaded

  • upload_url (String)

    The signed upload URL for the client to upload the file

  • media_url: (String)
  • upload_url: (String)


# File 'lib/post_for_me/models/media_create_upload_url_response.rb', line 19

Instance Attribute Details

#media_urlString

The public URL for the media, to use once file has been uploaded

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/post_for_me/models/media_create_upload_url_response.rb', line 11

required :media_url, String

#upload_urlString

The signed upload URL for the client to upload the file

Parameters:

  • value (String)

Returns:

  • (String)


17
# File 'lib/post_for_me/models/media_create_upload_url_response.rb', line 17

required :upload_url, String

Instance Method Details

#to_hash{ media_url: String, upload_url: String }

Returns:

  • ({ media_url: String, upload_url: String })


13
# File 'sig/post_for_me/models/media_create_upload_url_response.rbs', line 13

def to_hash: -> { media_url: String, upload_url: String }