Class: PostForMe::Models::PinterestMetricsWindow

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/post_for_me/models/pinterest_metrics_window.rb,
sig/post_for_me/models/pinterest_metrics_window.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(comment: nil, impression: nil, last_updated: nil, outbound_click: nil, pin_click: nil, profile_visit: nil, reaction: nil, save: nil, user_follow: nil, video_10s_views: nil, video_average_time: nil, video_p95_views: nil, video_total_time: nil, video_views: nil) ⇒ Object

Parameters:

  • comment (Float) (defaults to: nil)

    Number of comments on the Pin

  • impression (Float) (defaults to: nil)

    Number of times the Pin was shown (impressions)

  • last_updated (String) (defaults to: nil)

    The last time Pinterest updated these metrics

  • outbound_click (Float) (defaults to: nil)

    Number of clicks from the Pin to an external destination (outbound clicks)

  • pin_click (Float) (defaults to: nil)

    Number of clicks on the Pin to view it in closeup (Pin clicks)

  • profile_visit (Object, nil) (defaults to: nil)

    Number of visits to the author's profile driven from the Pin

  • reaction (Float) (defaults to: nil)

    Total number of reactions on the Pin

  • save (Float) (defaults to: nil)

    Number of saves of the Pin

  • user_follow (Object, nil) (defaults to: nil)

    Number of follows driven from the Pin

  • video_10s_views (Float) (defaults to: nil)

    Number of video views of at least 10 seconds

  • video_average_time (Float) (defaults to: nil)

    Average watch time for the video

  • video_p95_views (Float) (defaults to: nil)

    Number of video views that reached 95% completion

  • video_total_time (Float) (defaults to: nil)

    Total watch time for the video

  • video_views (Float) (defaults to: nil)

    Number of video views



# File 'lib/post_for_me/models/pinterest_metrics_window.rb', line 90

Instance Attribute Details

#commentFloat?

Number of comments on the Pin

Parameters:

  • (Float)

Returns:

  • (Float, nil)


10
# File 'lib/post_for_me/models/pinterest_metrics_window.rb', line 10

optional :comment, Float

#impressionFloat?

Number of times the Pin was shown (impressions)

Parameters:

  • (Float)

Returns:

  • (Float, nil)


16
# File 'lib/post_for_me/models/pinterest_metrics_window.rb', line 16

optional :impression, Float

#last_updatedString?

The last time Pinterest updated these metrics

Parameters:

  • (String)

Returns:

  • (String, nil)


22
# File 'lib/post_for_me/models/pinterest_metrics_window.rb', line 22

optional :last_updated, String

#outbound_clickFloat?

Number of clicks from the Pin to an external destination (outbound clicks)

Parameters:

  • (Float)

Returns:

  • (Float, nil)


28
# File 'lib/post_for_me/models/pinterest_metrics_window.rb', line 28

optional :outbound_click, Float

#pin_clickFloat?

Number of clicks on the Pin to view it in closeup (Pin clicks)

Parameters:

  • (Float)

Returns:

  • (Float, nil)


34
# File 'lib/post_for_me/models/pinterest_metrics_window.rb', line 34

optional :pin_click, Float

#profile_visitObject?

Number of visits to the author's profile driven from the Pin

Parameters:

  • value (top, nil)

Returns:

  • (Object, nil)


40
# File 'lib/post_for_me/models/pinterest_metrics_window.rb', line 40

optional :profile_visit, PostForMe::Internal::Type::Unknown, nil?: true

#reactionFloat?

Total number of reactions on the Pin

Parameters:

  • (Float)

Returns:

  • (Float, nil)


46
# File 'lib/post_for_me/models/pinterest_metrics_window.rb', line 46

optional :reaction, Float

#saveFloat?

Number of saves of the Pin

Parameters:

  • (Float)

Returns:

  • (Float, nil)


52
# File 'lib/post_for_me/models/pinterest_metrics_window.rb', line 52

optional :save, Float

#user_followObject?

Number of follows driven from the Pin

Parameters:

  • value (top, nil)

Returns:

  • (Object, nil)


58
# File 'lib/post_for_me/models/pinterest_metrics_window.rb', line 58

optional :user_follow, PostForMe::Internal::Type::Unknown, nil?: true

#video_10s_viewsFloat?

Number of video views of at least 10 seconds

Parameters:

  • (Float)

Returns:

  • (Float, nil)


64
# File 'lib/post_for_me/models/pinterest_metrics_window.rb', line 64

optional :video_10s_views, Float

#video_average_timeFloat?

Average watch time for the video

Parameters:

  • (Float)

Returns:

  • (Float, nil)


70
# File 'lib/post_for_me/models/pinterest_metrics_window.rb', line 70

optional :video_average_time, Float

#video_p95_viewsFloat?

Number of video views that reached 95% completion

Parameters:

  • (Float)

Returns:

  • (Float, nil)


76
# File 'lib/post_for_me/models/pinterest_metrics_window.rb', line 76

optional :video_p95_views, Float

#video_total_timeFloat?

Total watch time for the video

Parameters:

  • (Float)

Returns:

  • (Float, nil)


82
# File 'lib/post_for_me/models/pinterest_metrics_window.rb', line 82

optional :video_total_time, Float

#video_viewsFloat?

Number of video views

Parameters:

  • (Float)

Returns:

  • (Float, nil)


88
# File 'lib/post_for_me/models/pinterest_metrics_window.rb', line 88

optional :video_views, Float

Instance Method Details

#to_hash{

Returns:

  • ({)


91
# File 'sig/post_for_me/models/pinterest_metrics_window.rbs', line 91

def to_hash: -> {