Class: PostForMe::Models::PlatformPost::Metrics::FacebookPostMetricsDto
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PostForMe::Models::PlatformPost::Metrics::FacebookPostMetricsDto
- Defined in:
- lib/post_for_me/models/platform_post.rb,
sig/post_for_me/models/platform_post.rbs
Instance Attribute Summary collapse
-
#activity_by_action_type ⇒ Array<PostForMe::Models::FacebookActivityByActionType>?
Total activity breakdown by action type.
-
#activity_by_action_type_unique ⇒ Array<PostForMe::Models::FacebookActivityByActionType>?
Unique users activity breakdown by action type.
-
#comments ⇒ Float?
Number of comments (from post object).
-
#media_views ⇒ Float?
Number of times the photo or video was viewed.
-
#reach ⇒ Float?
Total number of unique people who viewed the post media.
-
#reactions_anger ⇒ Float?
Number of anger reactions.
-
#reactions_by_type ⇒ Object?
Breakdown of all reaction types.
-
#reactions_haha ⇒ Float?
Number of haha reactions.
-
#reactions_like ⇒ Float?
Number of like reactions.
-
#reactions_love ⇒ Float?
Number of love reactions.
-
#reactions_sorry ⇒ Float?
Number of sad reactions.
-
#reactions_total ⇒ Float?
Total number of reactions (all types).
-
#reactions_wow ⇒ Float?
Number of wow reactions.
-
#shares ⇒ Float?
Number of shares (from post object).
-
#video_avg_time_watched ⇒ Float?
Average time video was viewed in milliseconds.
-
#video_complete_views_organic ⇒ Float?
Number of times video was viewed to 95% organically.
-
#video_complete_views_organic_unique ⇒ Float?
Number of unique people who viewed video to 95% organically.
-
#video_complete_views_paid ⇒ Float?
Number of times video was viewed to 95% via paid distribution.
-
#video_complete_views_paid_unique ⇒ Float?
Number of unique people who viewed video to 95% via paid distribution.
-
#video_length ⇒ Float?
Length of the video in milliseconds.
-
#video_retention_graph_autoplayed ⇒ Array<PostForMe::Models::FacebookVideoRetentionGraph>?
Video retention graph for autoplayed views.
-
#video_retention_graph_clicked_to_play ⇒ Array<PostForMe::Models::FacebookVideoRetentionGraph>?
Video retention graph for clicked-to-play views.
-
#video_social_actions_unique ⇒ Float?
Number of unique people who performed social actions on the video.
-
#video_view_time ⇒ Float?
Total time video was viewed in milliseconds.
-
#video_view_time_by_age_gender ⇒ Array<PostForMe::Models::FacebookVideoViewTimeByDemographic>?
Video view time breakdown by age and gender.
-
#video_view_time_by_country ⇒ Array<PostForMe::Models::FacebookVideoViewTimeByDemographic>?
Video view time breakdown by country.
-
#video_view_time_by_distribution_type ⇒ Object?
Video view time breakdown by distribution type.
-
#video_view_time_by_region ⇒ Array<PostForMe::Models::FacebookVideoViewTimeByDemographic>?
Video view time breakdown by region.
-
#video_view_time_organic ⇒ Float?
Total time video was viewed in milliseconds via organic distribution.
-
#video_views ⇒ Float?
Number of times video was viewed for 3+ seconds.
-
#video_views_15s ⇒ Float?
Number of times video was viewed for 15+ seconds.
-
#video_views_60s ⇒ Float?
Number of times video was viewed for 60+ seconds (excludes videos shorter than 60s).
-
#video_views_autoplayed ⇒ Float?
Number of times video was autoplayed for 3+ seconds.
-
#video_views_by_distribution_type ⇒ Object?
Video views breakdown by distribution type.
-
#video_views_clicked_to_play ⇒ Float?
Number of times video was clicked to play for 3+ seconds.
-
#video_views_organic ⇒ Float?
Number of times video was viewed for 3+ seconds organically.
-
#video_views_paid ⇒ Float?
Number of times video was viewed for 3+ seconds via paid distribution.
-
#video_views_sound_on ⇒ Float?
Number of times video was viewed with sound on.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
856 |
# File 'sig/post_for_me/models/platform_post.rbs', line 856
def initialize: (
|
Instance Attribute Details
#activity_by_action_type ⇒ Array<PostForMe::Models::FacebookActivityByActionType>?
Total activity breakdown by action type
825 826 |
# File 'lib/post_for_me/models/platform_post.rb', line 825 optional :activity_by_action_type, -> { PostForMe::Internal::Type::ArrayOf[PostForMe::FacebookActivityByActionType] } |
#activity_by_action_type_unique ⇒ Array<PostForMe::Models::FacebookActivityByActionType>?
Unique users activity breakdown by action type
832 833 |
# File 'lib/post_for_me/models/platform_post.rb', line 832 optional :activity_by_action_type_unique, -> { PostForMe::Internal::Type::ArrayOf[PostForMe::FacebookActivityByActionType] } |
#comments ⇒ Float?
Number of comments (from post object)
839 |
# File 'lib/post_for_me/models/platform_post.rb', line 839 optional :comments, Float |
#media_views ⇒ Float?
Number of times the photo or video was viewed
845 |
# File 'lib/post_for_me/models/platform_post.rb', line 845 optional :media_views, Float |
#reach ⇒ Float?
Total number of unique people who viewed the post media
851 |
# File 'lib/post_for_me/models/platform_post.rb', line 851 optional :reach, Float |
#reactions_anger ⇒ Float?
Number of anger reactions
857 |
# File 'lib/post_for_me/models/platform_post.rb', line 857 optional :reactions_anger, Float |
#reactions_by_type ⇒ Object?
Breakdown of all reaction types
863 |
# File 'lib/post_for_me/models/platform_post.rb', line 863 optional :reactions_by_type, PostForMe::Internal::Type::Unknown |
#reactions_haha ⇒ Float?
Number of haha reactions
869 |
# File 'lib/post_for_me/models/platform_post.rb', line 869 optional :reactions_haha, Float |
#reactions_like ⇒ Float?
Number of like reactions
875 |
# File 'lib/post_for_me/models/platform_post.rb', line 875 optional :reactions_like, Float |
#reactions_love ⇒ Float?
Number of love reactions
881 |
# File 'lib/post_for_me/models/platform_post.rb', line 881 optional :reactions_love, Float |
#reactions_sorry ⇒ Float?
Number of sad reactions
887 |
# File 'lib/post_for_me/models/platform_post.rb', line 887 optional :reactions_sorry, Float |
#reactions_total ⇒ Float?
Total number of reactions (all types)
893 |
# File 'lib/post_for_me/models/platform_post.rb', line 893 optional :reactions_total, Float |
#reactions_wow ⇒ Float?
Number of wow reactions
899 |
# File 'lib/post_for_me/models/platform_post.rb', line 899 optional :reactions_wow, Float |
#shares ⇒ Float?
Number of shares (from post object)
905 |
# File 'lib/post_for_me/models/platform_post.rb', line 905 optional :shares, Float |
#video_avg_time_watched ⇒ Float?
Average time video was viewed in milliseconds
911 |
# File 'lib/post_for_me/models/platform_post.rb', line 911 optional :video_avg_time_watched, Float |
#video_complete_views_organic ⇒ Float?
Number of times video was viewed to 95% organically
917 |
# File 'lib/post_for_me/models/platform_post.rb', line 917 optional :video_complete_views_organic, Float |
#video_complete_views_organic_unique ⇒ Float?
Number of unique people who viewed video to 95% organically
923 |
# File 'lib/post_for_me/models/platform_post.rb', line 923 optional :video_complete_views_organic_unique, Float |
#video_complete_views_paid ⇒ Float?
Number of times video was viewed to 95% via paid distribution
929 |
# File 'lib/post_for_me/models/platform_post.rb', line 929 optional :video_complete_views_paid, Float |
#video_complete_views_paid_unique ⇒ Float?
Number of unique people who viewed video to 95% via paid distribution
935 |
# File 'lib/post_for_me/models/platform_post.rb', line 935 optional :video_complete_views_paid_unique, Float |
#video_length ⇒ Float?
Length of the video in milliseconds
941 |
# File 'lib/post_for_me/models/platform_post.rb', line 941 optional :video_length, Float |
#video_retention_graph_autoplayed ⇒ Array<PostForMe::Models::FacebookVideoRetentionGraph>?
Video retention graph for autoplayed views
947 948 |
# File 'lib/post_for_me/models/platform_post.rb', line 947 optional :video_retention_graph_autoplayed, -> { PostForMe::Internal::Type::ArrayOf[PostForMe::FacebookVideoRetentionGraph] } |
#video_retention_graph_clicked_to_play ⇒ Array<PostForMe::Models::FacebookVideoRetentionGraph>?
Video retention graph for clicked-to-play views
954 955 |
# File 'lib/post_for_me/models/platform_post.rb', line 954 optional :video_retention_graph_clicked_to_play, -> { PostForMe::Internal::Type::ArrayOf[PostForMe::FacebookVideoRetentionGraph] } |
#video_social_actions_unique ⇒ Float?
Number of unique people who performed social actions on the video
961 |
# File 'lib/post_for_me/models/platform_post.rb', line 961 optional :video_social_actions_unique, Float |
#video_view_time ⇒ Float?
Total time video was viewed in milliseconds
967 |
# File 'lib/post_for_me/models/platform_post.rb', line 967 optional :video_view_time, Float |
#video_view_time_by_age_gender ⇒ Array<PostForMe::Models::FacebookVideoViewTimeByDemographic>?
Video view time breakdown by age and gender
973 974 |
# File 'lib/post_for_me/models/platform_post.rb', line 973 optional :video_view_time_by_age_gender, -> { PostForMe::Internal::Type::ArrayOf[PostForMe::FacebookVideoViewTimeByDemographic] } |
#video_view_time_by_country ⇒ Array<PostForMe::Models::FacebookVideoViewTimeByDemographic>?
Video view time breakdown by country
980 981 |
# File 'lib/post_for_me/models/platform_post.rb', line 980 optional :video_view_time_by_country, -> { PostForMe::Internal::Type::ArrayOf[PostForMe::FacebookVideoViewTimeByDemographic] } |
#video_view_time_by_distribution_type ⇒ Object?
Video view time breakdown by distribution type
987 |
# File 'lib/post_for_me/models/platform_post.rb', line 987 optional :video_view_time_by_distribution_type, PostForMe::Internal::Type::Unknown |
#video_view_time_by_region ⇒ Array<PostForMe::Models::FacebookVideoViewTimeByDemographic>?
Video view time breakdown by region
993 994 |
# File 'lib/post_for_me/models/platform_post.rb', line 993 optional :video_view_time_by_region, -> { PostForMe::Internal::Type::ArrayOf[PostForMe::FacebookVideoViewTimeByDemographic] } |
#video_view_time_organic ⇒ Float?
Total time video was viewed in milliseconds via organic distribution
1000 |
# File 'lib/post_for_me/models/platform_post.rb', line 1000 optional :video_view_time_organic, Float |
#video_views ⇒ Float?
Number of times video was viewed for 3+ seconds
1006 |
# File 'lib/post_for_me/models/platform_post.rb', line 1006 optional :video_views, Float |
#video_views_15s ⇒ Float?
Number of times video was viewed for 15+ seconds
1012 |
# File 'lib/post_for_me/models/platform_post.rb', line 1012 optional :video_views_15s, Float |
#video_views_60s ⇒ Float?
Number of times video was viewed for 60+ seconds (excludes videos shorter than 60s)
1019 |
# File 'lib/post_for_me/models/platform_post.rb', line 1019 optional :video_views_60s, Float |
#video_views_autoplayed ⇒ Float?
Number of times video was autoplayed for 3+ seconds
1025 |
# File 'lib/post_for_me/models/platform_post.rb', line 1025 optional :video_views_autoplayed, Float |
#video_views_by_distribution_type ⇒ Object?
Video views breakdown by distribution type
1031 |
# File 'lib/post_for_me/models/platform_post.rb', line 1031 optional :video_views_by_distribution_type, PostForMe::Internal::Type::Unknown |
#video_views_clicked_to_play ⇒ Float?
Number of times video was clicked to play for 3+ seconds
1037 |
# File 'lib/post_for_me/models/platform_post.rb', line 1037 optional :video_views_clicked_to_play, Float |
#video_views_organic ⇒ Float?
Number of times video was viewed for 3+ seconds organically
1043 |
# File 'lib/post_for_me/models/platform_post.rb', line 1043 optional :video_views_organic, Float |
#video_views_paid ⇒ Float?
Number of times video was viewed for 3+ seconds via paid distribution
1049 |
# File 'lib/post_for_me/models/platform_post.rb', line 1049 optional :video_views_paid, Float |
#video_views_sound_on ⇒ Float?
Number of times video was viewed with sound on
1055 |
# File 'lib/post_for_me/models/platform_post.rb', line 1055 optional :video_views_sound_on, Float |
Instance Method Details
#to_hash ⇒ {
897 |
# File 'sig/post_for_me/models/platform_post.rbs', line 897
def to_hash: -> {
|