Class: PostForMe::Models::PlatformPost::Metrics::LinkedInPostMetricsDto

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/post_for_me/models/platform_post.rb,
sig/post_for_me/models/platform_post.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



1186
# File 'sig/post_for_me/models/platform_post.rbs', line 1186

def initialize: (

Instance Attribute Details

#click_countFloat?

Number of clicks

Parameters:

  • (Float)

Returns:

  • (Float, nil)


1361
# File 'lib/post_for_me/models/platform_post.rb', line 1361

optional :click_count, Float, api_name: :clickCount

#comment_countFloat?

Number of comments

Parameters:

  • (Float)

Returns:

  • (Float, nil)


1367
# File 'lib/post_for_me/models/platform_post.rb', line 1367

optional :comment_count, Float, api_name: :commentCount

#engagementFloat?

Engagement rate

Parameters:

  • (Float)

Returns:

  • (Float, nil)


1373
# File 'lib/post_for_me/models/platform_post.rb', line 1373

optional :engagement, Float

#impression_countFloat?

Number of impressions

Parameters:

  • (Float)

Returns:

  • (Float, nil)


1379
# File 'lib/post_for_me/models/platform_post.rb', line 1379

optional :impression_count, Float, api_name: :impressionCount

#like_countFloat?

Number of likes

Parameters:

  • (Float)

Returns:

  • (Float, nil)


1385
# File 'lib/post_for_me/models/platform_post.rb', line 1385

optional :like_count, Float, api_name: :likeCount

#share_countFloat?

Number of shares

Parameters:

  • (Float)

Returns:

  • (Float, nil)


1391
# File 'lib/post_for_me/models/platform_post.rb', line 1391

optional :share_count, Float, api_name: :shareCount

#time_watchedFloat?

TIME_WATCHED: The time the video was watched in milliseconds. Video auto-looping will continue to increase this metric for each subsequent play

Parameters:

  • (Float)

Returns:

  • (Float, nil)


1398
# File 'lib/post_for_me/models/platform_post.rb', line 1398

optional :time_watched, Float, api_name: :timeWatched

#time_watched_for_video_viewsFloat?

TIME_WATCHED_FOR_VIDEO_VIEWS: The time watched in milliseconds for video play-pause cycles that are at least 3 seconds. Video auto-looping will continue to increase this metric for each subsequent play. Analytics data for this metric will be available for six months

Parameters:

  • (Float)

Returns:

  • (Float, nil)


1407
# File 'lib/post_for_me/models/platform_post.rb', line 1407

optional :time_watched_for_video_views, Float, api_name: :timeWatchedForVideoViews

#video_viewFloat?

VIDEO_VIEW: Video views with play-pause cycles for at least 3 seconds. Auto-looping videos are counted as one when loaded. Each subsequent auto-looped play doesn't increase this metric. Analytics data for this metric won't be available after six months

Parameters:

  • (Float)

Returns:

  • (Float, nil)


1416
# File 'lib/post_for_me/models/platform_post.rb', line 1416

optional :video_view, Float, api_name: :videoView

#viewerFloat?

VIEWER: Unique viewers who made engaged plays on the video. Auto-looping videos are counted as one when loaded. Each subsequent auto-looped play doesn't increase this metric. Analytics data for this metric won't be available after six months

Parameters:

  • (Float)

Returns:

  • (Float, nil)


1425
# File 'lib/post_for_me/models/platform_post.rb', line 1425

optional :viewer, Float

Instance Method Details

#to_hash{

Returns:

  • ({)


1199
# File 'sig/post_for_me/models/platform_post.rbs', line 1199

def to_hash: -> {