Class: PostForMe::Models::PlatformPost::Metrics::TwitterPostMetricsDto

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/post_for_me/models/platform_post.rb,
sig/post_for_me/models/platform_post.rbs

Defined Under Namespace

Classes: NonPublicMetrics, OrganicMetrics, PublicMetrics

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(impression_count:, like_count:, reply_count:, retweet_count:, url_link_clicks:, user_profile_clicks:) ⇒ Object

Organic metrics for the Tweet (available to the Tweet owner)

Parameters:

  • impression_count (Float)

    Number of times this Tweet has been viewed organically

  • like_count (Float)

    Number of Likes of this Tweet from organic distribution

  • reply_count (Float)

    Number of Replies of this Tweet from organic distribution

  • retweet_count (Float)

    Number of Retweets of this Tweet from organic distribution

  • url_link_clicks (Float)

    Number of clicks on links in this Tweet from organic distribution

  • user_profile_clicks (Float)

    Number of clicks on the author's profile from organic distribution



# File 'lib/post_for_me/models/platform_post.rb', line 1159

Instance Attribute Details

#non_public_metricsPostForMe::Models::PlatformPost::Metrics::TwitterPostMetricsDto::NonPublicMetrics?

Non-public metrics for the Tweet (available to the Tweet owner or advertisers)



1144
1145
# File 'lib/post_for_me/models/platform_post.rb', line 1144

optional :non_public_metrics,
-> { PostForMe::PlatformPost::Metrics::TwitterPostMetricsDto::NonPublicMetrics }

#organic_metricsPostForMe::Models::PlatformPost::Metrics::TwitterPostMetricsDto::OrganicMetrics?

Organic metrics for the Tweet (available to the Tweet owner)



1151
# File 'lib/post_for_me/models/platform_post.rb', line 1151

optional :organic_metrics, -> { PostForMe::PlatformPost::Metrics::TwitterPostMetricsDto::OrganicMetrics }

#public_metricsPostForMe::Models::PlatformPost::Metrics::TwitterPostMetricsDto::PublicMetrics?

Publicly available metrics for the Tweet



1157
# File 'lib/post_for_me/models/platform_post.rb', line 1157

optional :public_metrics, -> { PostForMe::PlatformPost::Metrics::TwitterPostMetricsDto::PublicMetrics }

Instance Method Details

#to_hash{

Returns:

  • ({)


971
# File 'sig/post_for_me/models/platform_post.rbs', line 971

def to_hash: -> {