Class: PostForMe::Models::PlatformPost::Metrics::TwitterPostMetricsDto::NonPublicMetrics

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/post_for_me/models/platform_post.rb,
sig/post_for_me/models/platform_post.rbs

Overview

See Also:

  • PostForMe::Models::PlatformPost::Metrics::TwitterPostMetricsDto#non_public_metrics

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



991
# File 'sig/post_for_me/models/platform_post.rbs', line 991

def initialize: (

Instance Attribute Details

#impression_countFloat

Number of times this Tweet has been viewed via promoted distribution

Parameters:

  • value (Float)

Returns:

  • (Float)


1172
# File 'lib/post_for_me/models/platform_post.rb', line 1172

required :impression_count, Float

Number of clicks on links in this Tweet via promoted distribution

Parameters:

  • value (Float)

Returns:

  • (Float)


1178
# File 'lib/post_for_me/models/platform_post.rb', line 1178

required :url_link_clicks, Float

#user_profile_clicksFloat

Number of clicks on the author's profile via promoted distribution

Parameters:

  • value (Float)

Returns:

  • (Float)


1184
# File 'lib/post_for_me/models/platform_post.rb', line 1184

required :user_profile_clicks, Float

Instance Method Details

#to_hash{

Returns:

  • ({)


997
# File 'sig/post_for_me/models/platform_post.rbs', line 997

def to_hash: -> {