Class: PostForMe::Models::PlatformPost::Metrics::TwitterPostMetricsDto::OrganicMetrics

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/post_for_me/models/platform_post.rb,
sig/post_for_me/models/platform_post.rbs

Overview

See Also:

  • PostForMe::Models::PlatformPost::Metrics::TwitterPostMetricsDto#organic_metrics

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



1027
# File 'sig/post_for_me/models/platform_post.rbs', line 1027

def initialize: (

Instance Attribute Details

#impression_countFloat

Number of times this Tweet has been viewed organically

Parameters:

  • value (Float)

Returns:

  • (Float)


1202
# File 'lib/post_for_me/models/platform_post.rb', line 1202

required :impression_count, Float

#like_countFloat

Number of Likes of this Tweet from organic distribution

Parameters:

  • value (Float)

Returns:

  • (Float)


1208
# File 'lib/post_for_me/models/platform_post.rb', line 1208

required :like_count, Float

#reply_countFloat

Number of Replies of this Tweet from organic distribution

Parameters:

  • value (Float)

Returns:

  • (Float)


1214
# File 'lib/post_for_me/models/platform_post.rb', line 1214

required :reply_count, Float

#retweet_countFloat

Number of Retweets of this Tweet from organic distribution

Parameters:

  • value (Float)

Returns:

  • (Float)


1220
# File 'lib/post_for_me/models/platform_post.rb', line 1220

required :retweet_count, Float

Number of clicks on links in this Tweet from organic distribution

Parameters:

  • value (Float)

Returns:

  • (Float)


1226
# File 'lib/post_for_me/models/platform_post.rb', line 1226

required :url_link_clicks, Float

#user_profile_clicksFloat

Number of clicks on the author's profile from organic distribution

Parameters:

  • value (Float)

Returns:

  • (Float)


1232
# File 'lib/post_for_me/models/platform_post.rb', line 1232

required :user_profile_clicks, Float

Instance Method Details

#to_hash{

Returns:

  • ({)


1036
# File 'sig/post_for_me/models/platform_post.rbs', line 1036

def to_hash: -> {