Class: PostForMe::Models::SocialAccountCreateAuthURLParams::PlatformData::Linkedin
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PostForMe::Models::SocialAccountCreateAuthURLParams::PlatformData::Linkedin
- Defined in:
- lib/post_for_me/models/social_account_create_auth_url_params.rb,
sig/post_for_me/models/social_account_create_auth_url_params.rbs
Overview
Defined Under Namespace
Modules: ConnectionType
Instance Attribute Summary collapse
-
#connection_type ⇒ Symbol, PostForMe::Models::SocialAccountCreateAuthURLParams::PlatformData::Linkedin::ConnectionType
The type of connection; If using our provided credentials always use "organization".
-
#permission_overrides ⇒ Array<String>?
Override the default permissions/scopes requested during OAuth.
Instance Method Summary collapse
-
#initialize(connection_type:, permission_overrides: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Linkedin for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(connection_type:, permission_overrides: nil) ⇒ Object
Some parameter documentations has been truncated, see PostForMe::Models::SocialAccountCreateAuthURLParams::PlatformData::Linkedin for more details.
Additional data for connecting linkedin accounts
|
|
# File 'lib/post_for_me/models/social_account_create_auth_url_params.rb', line 263
|
Instance Attribute Details
#connection_type ⇒ Symbol, PostForMe::Models::SocialAccountCreateAuthURLParams::PlatformData::Linkedin::ConnectionType
The type of connection; If using our provided credentials always use "organization". If using your own credentials then only use "organization" if you are using the Community API
251 252 |
# File 'lib/post_for_me/models/social_account_create_auth_url_params.rb', line 251 required :connection_type, enum: -> { PostForMe::SocialAccountCreateAuthURLParams::PlatformData::Linkedin::ConnectionType } |
#permission_overrides ⇒ Array<String>?
Override the default permissions/scopes requested during OAuth. Default personal scopes: openid, w_member_social, profile, email. Default organization scopes: r_basicprofile, w_member_social, r_organization_social, w_organization_social, rw_organization_admin
261 |
# File 'lib/post_for_me/models/social_account_create_auth_url_params.rb', line 261 optional :permission_overrides, PostForMe::Internal::Type::ArrayOf[String] |
Instance Method Details
#to_hash ⇒ {
246 |
# File 'sig/post_for_me/models/social_account_create_auth_url_params.rbs', line 246
def to_hash: -> {
|