Class: PostForMe::Models::SocialAccountCreateAuthURLResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/post_for_me/models/social_account_create_auth_url_response.rb,
sig/post_for_me/models/social_account_create_auth_url_response.rbs

Overview

See Also:

  • PostForMe::Resources::SocialAccounts#create_auth_url

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(platform:, url:) ⇒ SocialAccountCreateAuthURLResponse

Returns a new instance of SocialAccountCreateAuthURLResponse.

Parameters:

  • platform (String)

    The social account provider

  • url (String)

    The url to redirect the user to, in order to connect their account

  • platform: (String)
  • url: (String)


# File 'lib/post_for_me/models/social_account_create_auth_url_response.rb', line 19

Instance Attribute Details

#platformString

The social account provider

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/post_for_me/models/social_account_create_auth_url_response.rb', line 11

required :platform, String

#urlString

The url to redirect the user to, in order to connect their account

Parameters:

  • value (String)

Returns:

  • (String)


17
# File 'lib/post_for_me/models/social_account_create_auth_url_response.rb', line 17

required :url, String

Instance Method Details

#to_hash{ platform: String, url: String }

Returns:

  • ({ platform: String, url: String })


13
# File 'sig/post_for_me/models/social_account_create_auth_url_response.rbs', line 13

def to_hash: -> { platform: String, url: String }