Class: PostForMe::Models::SocialAccountCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/post_for_me/models/social_account_create_params.rb,
sig/post_for_me/models/social_account_create_params.rbs

Overview

See Also:

  • PostForMe::Resources::SocialAccounts#create

Defined Under Namespace

Modules: Platform

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::PostForMe

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(access_token:, access_token_expires_at:, platform:, user_id:, external_id: nil, metadata: nil, refresh_token: nil, refresh_token_expires_at: nil, username: nil, request_options: {}) ⇒ Object

Parameters:

  • access_token (String)

    The access token of the social account

  • access_token_expires_at (Time)

    The access token expiration date of the social account

  • platform (Symbol, PostForMe::Models::SocialAccountCreateParams::Platform)

    The platform of the social account

  • user_id (String)

    The user id of the social account

  • external_id (String, nil) (defaults to: nil)

    The external id of the social account

  • metadata (Object) (defaults to: nil)

    The metadata of the social account

  • refresh_token (String, nil) (defaults to: nil)

    The refresh token of the social account

  • refresh_token_expires_at (Time, nil) (defaults to: nil)

    The refresh token expiration date of the social account

  • username (String, nil) (defaults to: nil)

    The platform's username of the social account

  • request_options (PostForMe::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/post_for_me/models/social_account_create_params.rb', line 64

Instance Attribute Details

#access_tokenString

The access token of the social account

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/post_for_me/models/social_account_create_params.rb', line 14

required :access_token, String

#access_token_expires_atTime

The access token expiration date of the social account

Parameters:

  • value (Time)

Returns:

  • (Time)


20
# File 'lib/post_for_me/models/social_account_create_params.rb', line 20

required :access_token_expires_at, Time

#external_idString?

The external id of the social account

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


38
# File 'lib/post_for_me/models/social_account_create_params.rb', line 38

optional :external_id, String, nil?: true

#metadataObject?

The metadata of the social account

Parameters:

  • (top)

Returns:

  • (Object, nil)


44
# File 'lib/post_for_me/models/social_account_create_params.rb', line 44

optional :metadata, PostForMe::Internal::Type::Unknown

#platformSymbol, PostForMe::Models::SocialAccountCreateParams::Platform

The platform of the social account

Parameters:

  • value (PostForMe::Models::SocialAccountCreateParams::platform)

Returns:



26
# File 'lib/post_for_me/models/social_account_create_params.rb', line 26

required :platform, enum: -> { PostForMe::SocialAccountCreateParams::Platform }

#refresh_tokenString?

The refresh token of the social account

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


50
# File 'lib/post_for_me/models/social_account_create_params.rb', line 50

optional :refresh_token, String, nil?: true

#refresh_token_expires_atTime?

The refresh token expiration date of the social account

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


56
# File 'lib/post_for_me/models/social_account_create_params.rb', line 56

optional :refresh_token_expires_at, Time, nil?: true

#user_idString

The user id of the social account

Parameters:

  • value (String)

Returns:

  • (String)


32
# File 'lib/post_for_me/models/social_account_create_params.rb', line 32

required :user_id, String

#usernameString?

The platform's username of the social account

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


62
# File 'lib/post_for_me/models/social_account_create_params.rb', line 62

optional :username, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


54
# File 'sig/post_for_me/models/social_account_create_params.rbs', line 54

def to_hash: -> {