Class: PostForMe::Models::SocialAccountFeedListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/post_for_me/models/social_account_feed_list_params.rb,
sig/post_for_me/models/social_account_feed_list_params.rbs

Overview

See Also:

  • PostForMe::Resources::SocialAccountFeeds#list

Defined Under Namespace

Modules: Expand

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::PostForMe

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



47
# File 'sig/post_for_me/models/social_account_feed_list_params.rbs', line 47

def initialize: (

Instance Attribute Details

#cursorString?

Cursor identifying next page of results

Parameters:

  • (String)

Returns:

  • (String, nil)


19
# File 'lib/post_for_me/models/social_account_feed_list_params.rb', line 19

optional :cursor, String

#expandArray<Symbol, PostForMe::Models::SocialAccountFeedListParams::Expand>?

Expand additional data in the response. Currently supports: "metrics" to include post analytics data.



26
27
# File 'lib/post_for_me/models/social_account_feed_list_params.rb', line 26

optional :expand,
-> { PostForMe::Internal::Type::ArrayOf[enum: PostForMe::SocialAccountFeedListParams::Expand] }

#external_post_idArray<String>?

Filter by Post for Me Social Postexternal ID. Multiple values imply OR logic (e.g., ?external_post_id=xxxxxx&external_post_id=yyyyyy).

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


34
# File 'lib/post_for_me/models/social_account_feed_list_params.rb', line 34

optional :external_post_id, PostForMe::Internal::Type::ArrayOf[String]

#limitFloat?

Number of items to return; Note: some platforms will have different max limits, in the case the provided limit is over the platform's limit we will return the max allowed by the platform.

Parameters:

  • (Float)

Returns:

  • (Float, nil)


42
# File 'lib/post_for_me/models/social_account_feed_list_params.rb', line 42

optional :limit, Float

#platform_post_idArray<String>?

Filter by the platform's id(s). Multiple values imply OR logic (e.g., ?social_post_id=spr_xxxxxx&social_post_id=spr_yyyyyy).

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


49
# File 'lib/post_for_me/models/social_account_feed_list_params.rb', line 49

optional :platform_post_id, PostForMe::Internal::Type::ArrayOf[String]

#social_account_idString

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/post_for_me/models/social_account_feed_list_params.rb', line 13

required :social_account_id, String

#social_post_idArray<String>?

Filter by Post for Me Social Post id(s). Multiple values imply OR logic (e.g., ?social_post_id=sp_xxxxxx&social_post_id=sp_yyyyyy).

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


56
# File 'lib/post_for_me/models/social_account_feed_list_params.rb', line 56

optional :social_post_id, PostForMe::Internal::Type::ArrayOf[String]

Instance Method Details

#to_hash{

Returns:

  • ({)


58
# File 'sig/post_for_me/models/social_account_feed_list_params.rbs', line 58

def to_hash: -> {