Class: PostForMe::Models::SocialAccountFeedListResponse::Meta

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/post_for_me/models/social_account_feed_list_response.rb,
sig/post_for_me/models/social_account_feed_list_response.rbs

Overview

See Also:

  • PostForMe::Models::SocialAccountFeedListResponse#meta

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(cursor:, limit:, next_:, has_more: nil) ⇒ Object

Parameters:

  • cursor (String)

    Id representing the next page of items

  • limit (Float)

    Maximum number of items returned.

  • next_ (String, nil)

    URL to the next page of results, or null if none.

  • has_more (Boolean) (defaults to: nil)

    Indicates if there are more results or not



# File 'lib/post_for_me/models/social_account_feed_list_response.rb', line 47

Instance Attribute Details

#cursorString

Id representing the next page of items

Parameters:

  • value (String)

Returns:

  • (String)


27
# File 'lib/post_for_me/models/social_account_feed_list_response.rb', line 27

required :cursor, String

#has_moreBoolean?

Indicates if there are more results or not

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


45
# File 'lib/post_for_me/models/social_account_feed_list_response.rb', line 45

optional :has_more, PostForMe::Internal::Type::Boolean

#limitFloat

Maximum number of items returned.

Parameters:

  • value (Float)

Returns:

  • (Float)


33
# File 'lib/post_for_me/models/social_account_feed_list_response.rb', line 33

required :limit, Float

#next_String?

URL to the next page of results, or null if none.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


39
# File 'lib/post_for_me/models/social_account_feed_list_response.rb', line 39

required :next_, String, api_name: :next, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


45
# File 'sig/post_for_me/models/social_account_feed_list_response.rbs', line 45

def to_hash: -> {