Class: PostForMe::Models::SocialPostListResponse::Meta

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/post_for_me/models/social_post_list_response.rb,
sig/post_for_me/models/social_post_list_response.rbs

Overview

See Also:

  • PostForMe::Models::SocialPostListResponse#meta

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(limit:, next_:, offset:, total:) ⇒ Object

Parameters:

  • limit (Float)

    Maximum number of items returned.

  • next_ (String, nil)

    URL to the next page of results, or null if none.

  • offset (Float)

    Number of items skipped.

  • total (Float)

    Total number of items available.



# File 'lib/post_for_me/models/social_post_list_response.rb', line 47

Instance Attribute Details

#limitFloat

Maximum number of items returned.

Parameters:

  • value (Float)

Returns:

  • (Float)


27
# File 'lib/post_for_me/models/social_post_list_response.rb', line 27

required :limit, Float

#next_String?

URL to the next page of results, or null if none.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


33
# File 'lib/post_for_me/models/social_post_list_response.rb', line 33

required :next_, String, api_name: :next, nil?: true

#offsetFloat

Number of items skipped.

Parameters:

  • value (Float)

Returns:

  • (Float)


39
# File 'lib/post_for_me/models/social_post_list_response.rb', line 39

required :offset, Float

#totalFloat

Total number of items available.

Parameters:

  • value (Float)

Returns:

  • (Float)


45
# File 'lib/post_for_me/models/social_post_list_response.rb', line 45

required :total, Float

Instance Method Details

#to_hash{

Returns:

  • ({)


42
# File 'sig/post_for_me/models/social_post_list_response.rbs', line 42

def to_hash: -> {