Class: PostForMe::Models::TiktokConfiguration

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/post_for_me/models/tiktok_configuration.rb,
sig/post_for_me/models/tiktok_configuration.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(allow_comment: nil, allow_duet: nil, allow_stitch: nil, auto_add_music: nil, caption: nil, disclose_branded_content: nil, disclose_your_brand: nil, is_ai_generated: nil, is_draft: nil, media: nil, privacy_status: nil, title: nil) ⇒ Object

Some parameter documentations has been truncated, see PostForMe::Models::TiktokConfiguration for more details.

Parameters:

  • allow_comment (Boolean, nil) (defaults to: nil)

    Allow comments on TikTok

  • allow_duet (Boolean, nil) (defaults to: nil)

    Allow duets on TikTok

  • allow_stitch (Boolean, nil) (defaults to: nil)

    Allow stitch on TikTok

  • auto_add_music (Boolean, nil) (defaults to: nil)

    Will automatically add music to photo posts

  • caption (Object, nil) (defaults to: nil)

    Overrides the caption from the post

  • disclose_branded_content (Boolean, nil) (defaults to: nil)

    Disclose branded content on TikTok

  • disclose_your_brand (Boolean, nil) (defaults to: nil)

    Disclose your brand on TikTok

  • is_ai_generated (Boolean, nil) (defaults to: nil)

    Flag content as AI generated on TikTok

  • is_draft (Boolean, nil) (defaults to: nil)

    Will create a draft upload to TikTok, posting will need to be completed from wit

  • media (Array<PostForMe::Models::SocialPostMedia>, nil) (defaults to: nil)

    Overrides the media from the post

  • privacy_status (String, nil) (defaults to: nil)

    Sets the privacy status for TikTok (private, public)

  • title (String, nil) (defaults to: nil)

    Overrides the title from the post



# File 'lib/post_for_me/models/tiktok_configuration.rb', line 79

Instance Attribute Details

#allow_commentBoolean?

Allow comments on TikTok

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


10
# File 'lib/post_for_me/models/tiktok_configuration.rb', line 10

optional :allow_comment, PostForMe::Internal::Type::Boolean, nil?: true

#allow_duetBoolean?

Allow duets on TikTok

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


16
# File 'lib/post_for_me/models/tiktok_configuration.rb', line 16

optional :allow_duet, PostForMe::Internal::Type::Boolean, nil?: true

#allow_stitchBoolean?

Allow stitch on TikTok

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


22
# File 'lib/post_for_me/models/tiktok_configuration.rb', line 22

optional :allow_stitch, PostForMe::Internal::Type::Boolean, nil?: true

#auto_add_musicBoolean?

Will automatically add music to photo posts

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


28
# File 'lib/post_for_me/models/tiktok_configuration.rb', line 28

optional :auto_add_music, PostForMe::Internal::Type::Boolean, nil?: true

#captionObject?

Overrides the caption from the post

Parameters:

  • value (top, nil)

Returns:

  • (Object, nil)


34
# File 'lib/post_for_me/models/tiktok_configuration.rb', line 34

optional :caption, PostForMe::Internal::Type::Unknown, nil?: true

#disclose_branded_contentBoolean?

Disclose branded content on TikTok

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


40
# File 'lib/post_for_me/models/tiktok_configuration.rb', line 40

optional :disclose_branded_content, PostForMe::Internal::Type::Boolean, nil?: true

#disclose_your_brandBoolean?

Disclose your brand on TikTok

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


46
# File 'lib/post_for_me/models/tiktok_configuration.rb', line 46

optional :disclose_your_brand, PostForMe::Internal::Type::Boolean, nil?: true

#is_ai_generatedBoolean?

Flag content as AI generated on TikTok

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


52
# File 'lib/post_for_me/models/tiktok_configuration.rb', line 52

optional :is_ai_generated, PostForMe::Internal::Type::Boolean, nil?: true

#is_draftBoolean?

Will create a draft upload to TikTok, posting will need to be completed from within the app

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


59
# File 'lib/post_for_me/models/tiktok_configuration.rb', line 59

optional :is_draft, PostForMe::Internal::Type::Boolean, nil?: true

#mediaArray<PostForMe::Models::SocialPostMedia>?

Overrides the media from the post

Parameters:

Returns:



65
# File 'lib/post_for_me/models/tiktok_configuration.rb', line 65

optional :media, -> { PostForMe::Internal::Type::ArrayOf[PostForMe::SocialPostMedia] }, nil?: true

#privacy_statusString?

Sets the privacy status for TikTok (private, public)

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


71
# File 'lib/post_for_me/models/tiktok_configuration.rb', line 71

optional :privacy_status, String, nil?: true

#titleString?

Overrides the title from the post

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


77
# File 'lib/post_for_me/models/tiktok_configuration.rb', line 77

optional :title, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


59
# File 'sig/post_for_me/models/tiktok_configuration.rbs', line 59

def to_hash: -> {