Class: PostForMe::Models::WebhookListResponse::Meta
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PostForMe::Models::WebhookListResponse::Meta
- Defined in:
- lib/post_for_me/models/webhook_list_response.rb,
sig/post_for_me/models/webhook_list_response.rbs
Overview
Instance Attribute Summary collapse
-
#limit ⇒ Float
Maximum number of items returned.
-
#next_ ⇒ String?
URL to the next page of results, or null if none.
-
#offset ⇒ Float
Number of items skipped.
-
#total ⇒ Float
Total number of items available.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(limit:, next_:, offset:, total:) ⇒ Object
|
|
# File 'lib/post_for_me/models/webhook_list_response.rb', line 47
|
Instance Attribute Details
#limit ⇒ Float
Maximum number of items returned.
27 |
# File 'lib/post_for_me/models/webhook_list_response.rb', line 27 required :limit, Float |
#next_ ⇒ String?
URL to the next page of results, or null if none.
33 |
# File 'lib/post_for_me/models/webhook_list_response.rb', line 33 required :next_, String, api_name: :next, nil?: true |
#offset ⇒ Float
Number of items skipped.
39 |
# File 'lib/post_for_me/models/webhook_list_response.rb', line 39 required :offset, Float |
#total ⇒ Float
Total number of items available.
45 |
# File 'lib/post_for_me/models/webhook_list_response.rb', line 45 required :total, Float |
Instance Method Details
#to_hash ⇒ {
42 |
# File 'sig/post_for_me/models/webhook_list_response.rbs', line 42
def to_hash: -> {
|