Class: PostForMe::Models::YoutubeConfigurationDto::Localization

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/post_for_me/models/youtube_configuration_dto.rb,
sig/post_for_me/models/youtube_configuration_dto.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(localizations:, caption: nil, category_id: nil, contains_synthetic_media: nil, default_language: nil, description: nil, embeddable: nil, license: nil, made_for_kids: nil, media: nil, privacy_status: nil, public_stats_viewable: nil, publish_at: nil, recording_date: nil, tags: nil, title: nil) ⇒ Localization

Some parameter documentations has been truncated, see PostForMe::Models::YoutubeConfigurationDto for more details.

Parameters:

  • localizations (Hash{Symbol=>PostForMe::Models::YoutubeConfigurationDto::Localization}, nil)

    Per-language localizations for the video title and description. Keys are BCP-47

  • caption (Object, nil) (defaults to: nil)

    Overrides the caption from the post

  • category_id (String, nil) (defaults to: nil)

    YouTube video category id (maps to snippet.categoryId; see YouTube Data API vide

  • contains_synthetic_media (Boolean, nil) (defaults to: nil)

    If true, marks the video as containing altered or synthetic content per YouTube'

  • default_language (String, nil) (defaults to: nil)

    Default language of the video (BCP-47 language tag, e.g. "en"). Maps to snippet.

  • description (String, nil) (defaults to: nil)

    Description for the YouTube video (maps to snippet.description). Falls back to t

  • embeddable (Boolean, nil) (defaults to: nil)

    If true the video can be embedded on other websites (maps to status.embeddable).

  • license (Symbol, PostForMe::Models::YoutubeConfigurationDto::License, nil) (defaults to: nil)

    The video's license (maps to status.license). "youtube" is the standard YouTube

  • made_for_kids (Boolean, nil) (defaults to: nil)

    If true will notify YouTube the video is intended for kids (maps to status.selfD

  • media (Array<PostForMe::Models::SocialPostMedia>, nil) (defaults to: nil)

    Overrides the media from the post

  • privacy_status (Symbol, PostForMe::Models::YoutubeConfigurationDto::PrivacyStatus, nil) (defaults to: nil)

    Sets the privacy status of the video (maps to status.privacyStatus), will defaul

  • public_stats_viewable (Boolean, nil) (defaults to: nil)

    If true, the extended video statistics are publicly viewable (maps to status.pub

  • publish_at (String, nil) (defaults to: nil)

    ISO 8601 datetime at which the video should be published. Only honoured when pri

  • recording_date (String, nil) (defaults to: nil)

    ISO 8601 date (YYYY-MM-DD) or datetime when the video was recorded (maps to reco

  • tags (Array<String>, nil) (defaults to: nil)

    YouTube video tags (maps to snippet.tags)

  • title (String, nil) (defaults to: nil)

    Overrides the title from the post (maps to snippet.title)

  • description: (String, nil) (defaults to: nil)
  • title: (String, nil) (defaults to: nil)


154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/post_for_me/models/youtube_configuration_dto.rb', line 154

class Localization < PostForMe::Internal::Type::BaseModel
  # @!attribute description
  #
  #   @return [String, nil]
  optional :description, String, nil?: true

  # @!attribute title
  #
  #   @return [String, nil]
  optional :title, String, nil?: true

  # @!method initialize(description: nil, title: nil)
  #   @param description [String, nil]
  #   @param title [String, nil]
end

Instance Attribute Details

#descriptionString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


158
# File 'lib/post_for_me/models/youtube_configuration_dto.rb', line 158

optional :description, String, nil?: true

#titleString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


163
# File 'lib/post_for_me/models/youtube_configuration_dto.rb', line 163

optional :title, String, nil?: true

Instance Method Details

#to_hash{ description: String?, title: String? }

Returns:

  • ({ description: String?, title: String? })


103
# File 'sig/post_for_me/models/youtube_configuration_dto.rbs', line 103

def to_hash: -> { description: String?, title: String? }