Class: PostForMe::Models::CreateSocialPost
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PostForMe::Models::CreateSocialPost
- Defined in:
- lib/post_for_me/models/create_social_post.rb,
sig/post_for_me/models/create_social_post.rbs
Direct Known Subclasses
Instance Attribute Summary collapse
-
#account_configurations ⇒ Array<PostForMe::Models::AccountConfiguration>?
Account-specific configurations for the post.
-
#caption ⇒ String
Caption text for the post.
-
#external_id ⇒ String?
Array of social account IDs for posting.
-
#is_draft ⇒ Boolean?
If isDraft is set then the post will not be processed.
-
#media ⇒ Array<PostForMe::Models::SocialPostMedia>?
Array of media associated with the post.
-
#platform_configurations ⇒ PostForMe::Models::PlatformConfigurationsDto?
Platform-specific configurations for the post.
-
#scheduled_at ⇒ Time?
Scheduled date and time for the post, setting to null or undefined will post instantly.
-
#social_accounts ⇒ Array<String>
Array of social account IDs for posting.
Instance Method Summary collapse
-
#initialize(caption:, social_accounts:, account_configurations: nil, external_id: nil, is_draft: nil, media: nil, platform_configurations: nil, scheduled_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see CreateSocialPost for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(caption:, social_accounts:, account_configurations: nil, external_id: nil, is_draft: nil, media: nil, platform_configurations: nil, scheduled_at: nil) ⇒ Object
Some parameter documentations has been truncated, see PostForMe::Models::CreateSocialPost for more details.
|
|
# File 'lib/post_for_me/models/create_social_post.rb', line 58
|
Instance Attribute Details
#account_configurations ⇒ Array<PostForMe::Models::AccountConfiguration>?
Account-specific configurations for the post
22 23 24 |
# File 'lib/post_for_me/models/create_social_post.rb', line 22 optional :account_configurations, -> { PostForMe::Internal::Type::ArrayOf[PostForMe::AccountConfiguration] }, nil?: true |
#caption ⇒ String
Caption text for the post
10 |
# File 'lib/post_for_me/models/create_social_post.rb', line 10 required :caption, String |
#external_id ⇒ String?
Array of social account IDs for posting
30 |
# File 'lib/post_for_me/models/create_social_post.rb', line 30 optional :external_id, String, nil?: true |
#is_draft ⇒ Boolean?
If isDraft is set then the post will not be processed
36 |
# File 'lib/post_for_me/models/create_social_post.rb', line 36 optional :is_draft, PostForMe::Internal::Type::Boolean, api_name: :isDraft, nil?: true |
#media ⇒ Array<PostForMe::Models::SocialPostMedia>?
Array of media associated with the post. If multiple media items are provided
and the placement is stories, individual posts are created per media item.
43 |
# File 'lib/post_for_me/models/create_social_post.rb', line 43 optional :media, -> { PostForMe::Internal::Type::ArrayOf[PostForMe::SocialPostMedia] }, nil?: true |
#platform_configurations ⇒ PostForMe::Models::PlatformConfigurationsDto?
Platform-specific configurations for the post
49 |
# File 'lib/post_for_me/models/create_social_post.rb', line 49 optional :platform_configurations, -> { PostForMe::PlatformConfigurationsDto }, nil?: true |
#scheduled_at ⇒ Time?
Scheduled date and time for the post, setting to null or undefined will post instantly
56 |
# File 'lib/post_for_me/models/create_social_post.rb', line 56 optional :scheduled_at, Time, nil?: true |
#social_accounts ⇒ Array<String>
Array of social account IDs for posting
16 |
# File 'lib/post_for_me/models/create_social_post.rb', line 16 required :social_accounts, PostForMe::Internal::Type::ArrayOf[String] |
Instance Method Details
#to_hash ⇒ {
43 |
# File 'sig/post_for_me/models/create_social_post.rbs', line 43
def to_hash: -> {
|