Class: PostForMe::Models::FacebookConfigurationDto
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PostForMe::Models::FacebookConfigurationDto
- Defined in:
- lib/post_for_me/models/facebook_configuration_dto.rb,
sig/post_for_me/models/facebook_configuration_dto.rbs
Defined Under Namespace
Modules: Placement
Instance Attribute Summary collapse
-
#caption ⇒ Object?
Overrides the
captionfrom the post. -
#collaborators ⇒ Array<Array<Object>>?
List of page ids to invite as collaborators for a Video Reel.
-
#location ⇒ String?
Page id with a location that you want to tag the image or video with.
-
#media ⇒ Array<PostForMe::Models::SocialPostMedia>?
Overrides the
mediafrom the post. -
#placement ⇒ Symbol, ...
Facebook post placement.
-
#set_caption_for_each_image ⇒ Boolean?
If true, include the caption on each image in a carousel upload; if false, only include it on the final carousel post.
Instance Method Summary collapse
-
#initialize(caption: nil, collaborators: nil, location: nil, media: nil, placement: nil, set_caption_for_each_image: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see FacebookConfigurationDto for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(caption: nil, collaborators: nil, location: nil, media: nil, placement: nil, set_caption_for_each_image: nil) ⇒ Object
Some parameter documentations has been truncated, see PostForMe::Models::FacebookConfigurationDto for more details.
|
|
# File 'lib/post_for_me/models/facebook_configuration_dto.rb', line 45
|
Instance Attribute Details
#caption ⇒ Object?
Overrides the caption from the post
10 |
# File 'lib/post_for_me/models/facebook_configuration_dto.rb', line 10 optional :caption, PostForMe::Internal::Type::Unknown, nil?: true |
#collaborators ⇒ Array<Array<Object>>?
List of page ids to invite as collaborators for a Video Reel
16 17 18 |
# File 'lib/post_for_me/models/facebook_configuration_dto.rb', line 16 optional :collaborators, PostForMe::Internal::Type::ArrayOf[PostForMe::Internal::Type::ArrayOf[PostForMe::Internal::Type::Unknown]], nil?: true |
#location ⇒ String?
Page id with a location that you want to tag the image or video with
24 |
# File 'lib/post_for_me/models/facebook_configuration_dto.rb', line 24 optional :location, String, nil?: true |
#media ⇒ Array<PostForMe::Models::SocialPostMedia>?
Overrides the media from the post
30 |
# File 'lib/post_for_me/models/facebook_configuration_dto.rb', line 30 optional :media, -> { PostForMe::Internal::Type::ArrayOf[PostForMe::SocialPostMedia] }, nil?: true |
#placement ⇒ Symbol, ...
Facebook post placement
36 |
# File 'lib/post_for_me/models/facebook_configuration_dto.rb', line 36 optional :placement, enum: -> { PostForMe::FacebookConfigurationDto::Placement }, nil?: true |
#set_caption_for_each_image ⇒ Boolean?
If true, include the caption on each image in a carousel upload; if false, only include it on the final carousel post
43 |
# File 'lib/post_for_me/models/facebook_configuration_dto.rb', line 43 optional :set_caption_for_each_image, PostForMe::Internal::Type::Boolean, nil?: true |
Instance Method Details
#to_hash ⇒ {
35 |
# File 'sig/post_for_me/models/facebook_configuration_dto.rbs', line 35
def to_hash: -> {
|