Class: PostForMe::Models::InstagramConfigurationDto
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PostForMe::Models::InstagramConfigurationDto
- Defined in:
- lib/post_for_me/models/instagram_configuration_dto.rb,
sig/post_for_me/models/instagram_configuration_dto.rbs
Defined Under Namespace
Modules: Placement, TrialReelType
Instance Attribute Summary collapse
-
#audio_name ⇒ String?
Display name for the audio track on Instagram Reels.
-
#caption ⇒ Object?
Overrides the
captionfrom the post. -
#collaborators ⇒ Array<String>?
Instagram usernames to be tagged as a collaborator.
-
#location ⇒ String?
Page id with a location that you want to tag the image or video with.
-
#media ⇒ Array<PostForMe::Models::SocialPostMedia>?
Overrides the
mediafrom the post. -
#placement ⇒ Symbol, ...
Instagram post placement.
-
#share_to_feed ⇒ Boolean?
If false video posts will only be shown in the Reels tab.
-
#trial_reel_type ⇒ Symbol, ...
Instagram trial reel type, when passed will be created as a trial reel.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(audio_name: nil, caption: nil, collaborators: nil, location: nil, media: nil, placement: nil, share_to_feed: nil, trial_reel_type: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see InstagramConfigurationDto for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(audio_name: nil, caption: nil, collaborators: nil, location: nil, media: nil, placement: nil, share_to_feed: nil, trial_reel_type: nil) ⇒ Object
Some parameter documentations has been truncated, see PostForMe::Models::InstagramConfigurationDto for more details.
|
|
# File 'lib/post_for_me/models/instagram_configuration_dto.rb', line 58
|
Instance Attribute Details
#audio_name ⇒ String?
Display name for the audio track on Instagram Reels. Only honored on Reels uploads, and only when the audio is original (Meta silently ignores it on licensed/fingerprinted tracks).
12 |
# File 'lib/post_for_me/models/instagram_configuration_dto.rb', line 12 optional :audio_name, String, nil?: true |
#caption ⇒ Object?
Overrides the caption from the post
18 |
# File 'lib/post_for_me/models/instagram_configuration_dto.rb', line 18 optional :caption, PostForMe::Internal::Type::Unknown, nil?: true |
#collaborators ⇒ Array<String>?
Instagram usernames to be tagged as a collaborator
24 |
# File 'lib/post_for_me/models/instagram_configuration_dto.rb', line 24 optional :collaborators, PostForMe::Internal::Type::ArrayOf[String], nil?: true |
#location ⇒ String?
Page id with a location that you want to tag the image or video with
30 |
# File 'lib/post_for_me/models/instagram_configuration_dto.rb', line 30 optional :location, String, nil?: true |
#media ⇒ Array<PostForMe::Models::SocialPostMedia>?
Overrides the media from the post
36 |
# File 'lib/post_for_me/models/instagram_configuration_dto.rb', line 36 optional :media, -> { PostForMe::Internal::Type::ArrayOf[PostForMe::SocialPostMedia] }, nil?: true |
#placement ⇒ Symbol, ...
Instagram post placement
42 |
# File 'lib/post_for_me/models/instagram_configuration_dto.rb', line 42 optional :placement, enum: -> { PostForMe::InstagramConfigurationDto::Placement }, nil?: true |
#share_to_feed ⇒ Boolean?
If false video posts will only be shown in the Reels tab
48 |
# File 'lib/post_for_me/models/instagram_configuration_dto.rb', line 48 optional :share_to_feed, PostForMe::Internal::Type::Boolean, nil?: true |
#trial_reel_type ⇒ Symbol, ...
Instagram trial reel type, when passed will be created as a trial reel. If manual the trial reel can be manually graduated in the native app. If perfomance the trial reel will be automatically graduated if the trial reel performs well.
56 |
# File 'lib/post_for_me/models/instagram_configuration_dto.rb', line 56 optional :trial_reel_type, enum: -> { PostForMe::InstagramConfigurationDto::TrialReelType }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/post_for_me/models/instagram_configuration_dto.rb', line 88
|
Instance Method Details
#to_hash ⇒ {
43 |
# File 'sig/post_for_me/models/instagram_configuration_dto.rbs', line 43
def to_hash: -> {
|