Class: PostForMe::Models::MediaCreateUploadURLResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PostForMe::Models::MediaCreateUploadURLResponse
- Defined in:
- lib/post_for_me/models/media_create_upload_url_response.rb,
sig/post_for_me/models/media_create_upload_url_response.rbs
Overview
Instance Attribute Summary collapse
-
#media_url ⇒ String
The public URL for the media, to use once file has been uploaded.
-
#upload_url ⇒ String
The signed upload URL for the client to upload the file.
Instance Method Summary collapse
-
#initialize(media_url:, upload_url:) ⇒ MediaCreateUploadURLResponse
constructor
A new instance of MediaCreateUploadURLResponse.
- #to_hash ⇒ { media_url: String, upload_url: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(media_url:, upload_url:) ⇒ MediaCreateUploadURLResponse
Returns a new instance of MediaCreateUploadURLResponse.
|
|
# File 'lib/post_for_me/models/media_create_upload_url_response.rb', line 19
|
Instance Attribute Details
#media_url ⇒ String
The public URL for the media, to use once file has been uploaded
11 |
# File 'lib/post_for_me/models/media_create_upload_url_response.rb', line 11 required :media_url, String |
#upload_url ⇒ String
The signed upload URL for the client to upload the file
17 |
# File 'lib/post_for_me/models/media_create_upload_url_response.rb', line 17 required :upload_url, String |
Instance Method Details
#to_hash ⇒ { media_url: String, upload_url: String }
13 |
# File 'sig/post_for_me/models/media_create_upload_url_response.rbs', line 13
def to_hash: -> { media_url: String, upload_url: String }
|