Class: PostForMe::Models::PinterestMetricsWindow
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PostForMe::Models::PinterestMetricsWindow
- Defined in:
- lib/post_for_me/models/pinterest_metrics_window.rb,
sig/post_for_me/models/pinterest_metrics_window.rbs
Instance Attribute Summary collapse
-
#comment ⇒ Float?
Number of comments on the Pin.
-
#impression ⇒ Float?
Number of times the Pin was shown (impressions).
-
#last_updated ⇒ String?
The last time Pinterest updated these metrics.
-
#outbound_click ⇒ Float?
Number of clicks from the Pin to an external destination (outbound clicks).
-
#pin_click ⇒ Float?
Number of clicks on the Pin to view it in closeup (Pin clicks).
-
#profile_visit ⇒ Object?
Number of visits to the author's profile driven from the Pin.
-
#reaction ⇒ Float?
Total number of reactions on the Pin.
-
#save ⇒ Float?
Number of saves of the Pin.
-
#user_follow ⇒ Object?
Number of follows driven from the Pin.
-
#video_10s_views ⇒ Float?
Number of video views of at least 10 seconds.
-
#video_average_time ⇒ Float?
Average watch time for the video.
-
#video_p95_views ⇒ Float?
Number of video views that reached 95% completion.
-
#video_total_time ⇒ Float?
Total watch time for the video.
-
#video_views ⇒ Float?
Number of video views.
Instance Method Summary collapse
- #initialize(comment: nil, impression: nil, last_updated: nil, outbound_click: nil, pin_click: nil, profile_visit: nil, reaction: nil, save: nil, user_follow: nil, video_10s_views: nil, video_average_time: nil, video_p95_views: nil, video_total_time: nil, video_views: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(comment: nil, impression: nil, last_updated: nil, outbound_click: nil, pin_click: nil, profile_visit: nil, reaction: nil, save: nil, user_follow: nil, video_10s_views: nil, video_average_time: nil, video_p95_views: nil, video_total_time: nil, video_views: nil) ⇒ Object
|
|
# File 'lib/post_for_me/models/pinterest_metrics_window.rb', line 90
|
Instance Attribute Details
#comment ⇒ Float?
Number of comments on the Pin
10 |
# File 'lib/post_for_me/models/pinterest_metrics_window.rb', line 10 optional :comment, Float |
#impression ⇒ Float?
Number of times the Pin was shown (impressions)
16 |
# File 'lib/post_for_me/models/pinterest_metrics_window.rb', line 16 optional :impression, Float |
#last_updated ⇒ String?
The last time Pinterest updated these metrics
22 |
# File 'lib/post_for_me/models/pinterest_metrics_window.rb', line 22 optional :last_updated, String |
#outbound_click ⇒ Float?
Number of clicks from the Pin to an external destination (outbound clicks)
28 |
# File 'lib/post_for_me/models/pinterest_metrics_window.rb', line 28 optional :outbound_click, Float |
#pin_click ⇒ Float?
Number of clicks on the Pin to view it in closeup (Pin clicks)
34 |
# File 'lib/post_for_me/models/pinterest_metrics_window.rb', line 34 optional :pin_click, Float |
#profile_visit ⇒ Object?
Number of visits to the author's profile driven from the Pin
40 |
# File 'lib/post_for_me/models/pinterest_metrics_window.rb', line 40 optional :profile_visit, PostForMe::Internal::Type::Unknown, nil?: true |
#reaction ⇒ Float?
Total number of reactions on the Pin
46 |
# File 'lib/post_for_me/models/pinterest_metrics_window.rb', line 46 optional :reaction, Float |
#save ⇒ Float?
Number of saves of the Pin
52 |
# File 'lib/post_for_me/models/pinterest_metrics_window.rb', line 52 optional :save, Float |
#user_follow ⇒ Object?
Number of follows driven from the Pin
58 |
# File 'lib/post_for_me/models/pinterest_metrics_window.rb', line 58 optional :user_follow, PostForMe::Internal::Type::Unknown, nil?: true |
#video_10s_views ⇒ Float?
Number of video views of at least 10 seconds
64 |
# File 'lib/post_for_me/models/pinterest_metrics_window.rb', line 64 optional :video_10s_views, Float |
#video_average_time ⇒ Float?
Average watch time for the video
70 |
# File 'lib/post_for_me/models/pinterest_metrics_window.rb', line 70 optional :video_average_time, Float |
#video_p95_views ⇒ Float?
Number of video views that reached 95% completion
76 |
# File 'lib/post_for_me/models/pinterest_metrics_window.rb', line 76 optional :video_p95_views, Float |
#video_total_time ⇒ Float?
Total watch time for the video
82 |
# File 'lib/post_for_me/models/pinterest_metrics_window.rb', line 82 optional :video_total_time, Float |
#video_views ⇒ Float?
Number of video views
88 |
# File 'lib/post_for_me/models/pinterest_metrics_window.rb', line 88 optional :video_views, Float |
Instance Method Details
#to_hash ⇒ {
91 |
# File 'sig/post_for_me/models/pinterest_metrics_window.rbs', line 91
def to_hash: -> {
|