Class: PostForMe::Models::PlatformPost::Metrics::TwitterPostMetricsDto::OrganicMetrics
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PostForMe::Models::PlatformPost::Metrics::TwitterPostMetricsDto::OrganicMetrics
- Defined in:
- lib/post_for_me/models/platform_post.rb,
sig/post_for_me/models/platform_post.rbs
Overview
Instance Attribute Summary collapse
-
#impression_count ⇒ Float
Number of times this Tweet has been viewed organically.
-
#like_count ⇒ Float
Number of Likes of this Tweet from organic distribution.
-
#reply_count ⇒ Float
Number of Replies of this Tweet from organic distribution.
-
#retweet_count ⇒ Float
Number of Retweets of this Tweet from organic distribution.
-
#url_link_clicks ⇒ Float
Number of clicks on links in this Tweet from organic distribution.
-
#user_profile_clicks ⇒ Float
Number of clicks on the author's profile from organic distribution.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
1027 |
# File 'sig/post_for_me/models/platform_post.rbs', line 1027
def initialize: (
|
Instance Attribute Details
#impression_count ⇒ Float
Number of times this Tweet has been viewed organically
1202 |
# File 'lib/post_for_me/models/platform_post.rb', line 1202 required :impression_count, Float |
#like_count ⇒ Float
Number of Likes of this Tweet from organic distribution
1208 |
# File 'lib/post_for_me/models/platform_post.rb', line 1208 required :like_count, Float |
#reply_count ⇒ Float
Number of Replies of this Tweet from organic distribution
1214 |
# File 'lib/post_for_me/models/platform_post.rb', line 1214 required :reply_count, Float |
#retweet_count ⇒ Float
Number of Retweets of this Tweet from organic distribution
1220 |
# File 'lib/post_for_me/models/platform_post.rb', line 1220 required :retweet_count, Float |
#url_link_clicks ⇒ Float
Number of clicks on links in this Tweet from organic distribution
1226 |
# File 'lib/post_for_me/models/platform_post.rb', line 1226 required :url_link_clicks, Float |
#user_profile_clicks ⇒ Float
Number of clicks on the author's profile from organic distribution
1232 |
# File 'lib/post_for_me/models/platform_post.rb', line 1232 required :user_profile_clicks, Float |
Instance Method Details
#to_hash ⇒ {
1036 |
# File 'sig/post_for_me/models/platform_post.rbs', line 1036
def to_hash: -> {
|