Class: PostForMe::Models::SocialAccountCreateAuthURLParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PostForMe::Models::SocialAccountCreateAuthURLParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/post_for_me/models/social_account_create_auth_url_params.rb,
sig/post_for_me/models/social_account_create_auth_url_params.rbs
Overview
Defined Under Namespace
Modules: Permission Classes: PlatformData
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::PostForMe
Instance Attribute Summary collapse
-
#external_id ⇒ String?
Your unique identifier for the social account.
-
#permissions ⇒ Array<Symbol, PostForMe::Models::SocialAccountCreateAuthURLParams::Permission>?
List of permissions you want to allow.
-
#platform ⇒ String
The social account provider.
-
#platform_data ⇒ PostForMe::Models::SocialAccountCreateAuthURLParams::PlatformData?
Additional data needed for the provider.
-
#redirect_url_override ⇒ String?
Override the default redirect URL for the OAuth flow.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
39 |
# File 'sig/post_for_me/models/social_account_create_auth_url_params.rbs', line 39
def initialize: (
|
Instance Attribute Details
#external_id ⇒ String?
Your unique identifier for the social account
20 |
# File 'lib/post_for_me/models/social_account_create_auth_url_params.rb', line 20 optional :external_id, String |
#permissions ⇒ Array<Symbol, PostForMe::Models::SocialAccountCreateAuthURLParams::Permission>?
List of permissions you want to allow. Will default to only post permissions. You must include the "feeds" permission to request an account feed and metrics
27 28 |
# File 'lib/post_for_me/models/social_account_create_auth_url_params.rb', line 27 optional :permissions, -> { PostForMe::Internal::Type::ArrayOf[enum: PostForMe::SocialAccountCreateAuthURLParams::Permission] } |
#platform ⇒ String
The social account provider
14 |
# File 'lib/post_for_me/models/social_account_create_auth_url_params.rb', line 14 required :platform, String |
#platform_data ⇒ PostForMe::Models::SocialAccountCreateAuthURLParams::PlatformData?
Additional data needed for the provider
34 |
# File 'lib/post_for_me/models/social_account_create_auth_url_params.rb', line 34 optional :platform_data, -> { PostForMe::SocialAccountCreateAuthURLParams::PlatformData } |
#redirect_url_override ⇒ String?
Override the default redirect URL for the OAuth flow. If provided, this URL will be used instead of our redirect URL. Make sure this URL is included in your app's authorized redirect urls. This override will not work when using our system credentials; configure the project redirect URL in the dashboard instead.
43 |
# File 'lib/post_for_me/models/social_account_create_auth_url_params.rb', line 43 optional :redirect_url_override, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/post_for_me/models/social_account_create_auth_url_params.rb', line 67
|
Instance Method Details
#to_hash ⇒ {
48 |
# File 'sig/post_for_me/models/social_account_create_auth_url_params.rbs', line 48
def to_hash: -> {
|