Class: PostForMe::Models::SocialAccountFeedListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PostForMe::Models::SocialAccountFeedListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/post_for_me/models/social_account_feed_list_params.rb,
sig/post_for_me/models/social_account_feed_list_params.rbs
Overview
Defined Under Namespace
Modules: Expand
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::PostForMe
Instance Attribute Summary collapse
-
#cursor ⇒ String?
Cursor identifying next page of results.
-
#expand ⇒ Array<Symbol, PostForMe::Models::SocialAccountFeedListParams::Expand>?
Expand additional data in the response.
-
#external_post_id ⇒ Array<String>?
Filter by Post for Me Social Postexternal ID.
-
#limit ⇒ Float?
Number of items to return; Note: some platforms will have different max limits, in the case the provided limit is over the platform's limit we will return the max allowed by the platform.
-
#platform_post_id ⇒ Array<String>?
Filter by the platform's id(s).
- #social_account_id ⇒ String
-
#social_post_id ⇒ Array<String>?
Filter by Post for Me Social Post id(s).
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
47 |
# File 'sig/post_for_me/models/social_account_feed_list_params.rbs', line 47
def initialize: (
|
Instance Attribute Details
#cursor ⇒ String?
Cursor identifying next page of results
19 |
# File 'lib/post_for_me/models/social_account_feed_list_params.rb', line 19 optional :cursor, String |
#expand ⇒ Array<Symbol, PostForMe::Models::SocialAccountFeedListParams::Expand>?
Expand additional data in the response. Currently supports: "metrics" to include post analytics data.
26 27 |
# File 'lib/post_for_me/models/social_account_feed_list_params.rb', line 26 optional :expand, -> { PostForMe::Internal::Type::ArrayOf[enum: PostForMe::SocialAccountFeedListParams::Expand] } |
#external_post_id ⇒ Array<String>?
Filter by Post for Me Social Postexternal ID. Multiple values imply OR logic (e.g., ?external_post_id=xxxxxx&external_post_id=yyyyyy).
34 |
# File 'lib/post_for_me/models/social_account_feed_list_params.rb', line 34 optional :external_post_id, PostForMe::Internal::Type::ArrayOf[String] |
#limit ⇒ Float?
Number of items to return; Note: some platforms will have different max limits, in the case the provided limit is over the platform's limit we will return the max allowed by the platform.
42 |
# File 'lib/post_for_me/models/social_account_feed_list_params.rb', line 42 optional :limit, Float |
#platform_post_id ⇒ Array<String>?
Filter by the platform's id(s). Multiple values imply OR logic (e.g., ?social_post_id=spr_xxxxxx&social_post_id=spr_yyyyyy).
49 |
# File 'lib/post_for_me/models/social_account_feed_list_params.rb', line 49 optional :platform_post_id, PostForMe::Internal::Type::ArrayOf[String] |
#social_account_id ⇒ String
13 |
# File 'lib/post_for_me/models/social_account_feed_list_params.rb', line 13 required :social_account_id, String |
#social_post_id ⇒ Array<String>?
Filter by Post for Me Social Post id(s). Multiple values imply OR logic (e.g., ?social_post_id=sp_xxxxxx&social_post_id=sp_yyyyyy).
56 |
# File 'lib/post_for_me/models/social_account_feed_list_params.rb', line 56 optional :social_post_id, PostForMe::Internal::Type::ArrayOf[String] |
Instance Method Details
#to_hash ⇒ {
58 |
# File 'sig/post_for_me/models/social_account_feed_list_params.rbs', line 58
def to_hash: -> {
|