Class: PostForMe::Models::SocialAccountFeedListResponse::Meta
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PostForMe::Models::SocialAccountFeedListResponse::Meta
- Defined in:
- lib/post_for_me/models/social_account_feed_list_response.rb,
sig/post_for_me/models/social_account_feed_list_response.rbs
Overview
Instance Attribute Summary collapse
-
#cursor ⇒ String
Id representing the next page of items.
-
#has_more ⇒ Boolean?
Indicates if there are more results or not.
-
#limit ⇒ Float
Maximum number of items returned.
-
#next_ ⇒ String?
URL to the next page of results, or null if none.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(cursor:, limit:, next_:, has_more: nil) ⇒ Object
|
|
# File 'lib/post_for_me/models/social_account_feed_list_response.rb', line 47
|
Instance Attribute Details
#cursor ⇒ String
Id representing the next page of items
27 |
# File 'lib/post_for_me/models/social_account_feed_list_response.rb', line 27 required :cursor, String |
#has_more ⇒ Boolean?
Indicates if there are more results or not
45 |
# File 'lib/post_for_me/models/social_account_feed_list_response.rb', line 45 optional :has_more, PostForMe::Internal::Type::Boolean |
#limit ⇒ Float
Maximum number of items returned.
33 |
# File 'lib/post_for_me/models/social_account_feed_list_response.rb', line 33 required :limit, Float |
#next_ ⇒ String?
URL to the next page of results, or null if none.
39 |
# File 'lib/post_for_me/models/social_account_feed_list_response.rb', line 39 required :next_, String, api_name: :next, nil?: true |
Instance Method Details
#to_hash ⇒ {
45 |
# File 'sig/post_for_me/models/social_account_feed_list_response.rbs', line 45
def to_hash: -> {
|