Class: PostForMe::Models::SocialPostMedia
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PostForMe::Models::SocialPostMedia
- Defined in:
- lib/post_for_me/models/social_post_media.rb,
sig/post_for_me/models/social_post_media.rbs
Defined Under Namespace
Classes: Tag
Instance Attribute Summary collapse
-
#skip_processing ⇒ Boolean?
If true the media will not be processed at all and instead be posted as is, this may increase chance of post failure if media does not meet platform's requirements.
-
#tags ⇒ Array<PostForMe::Models::SocialPostMedia::Tag>?
List of tags to attach to the media.
-
#thumbnail_timestamp_ms ⇒ Object?
Timestamp in milliseconds of frame to use as thumbnail for the media.
-
#thumbnail_url ⇒ Object?
Public URL of the thumbnail for the media.
-
#url ⇒ String
Public URL of the media.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
23 |
# File 'sig/post_for_me/models/social_post_media.rbs', line 23
def initialize: (
|
Instance Attribute Details
#skip_processing ⇒ Boolean?
If true the media will not be processed at all and instead be posted as is, this may increase chance of post failure if media does not meet platform's requirements. Best used for larger files.
18 |
# File 'lib/post_for_me/models/social_post_media.rb', line 18 optional :skip_processing, PostForMe::Internal::Type::Boolean, nil?: true |
#tags ⇒ Array<PostForMe::Models::SocialPostMedia::Tag>?
List of tags to attach to the media
24 |
# File 'lib/post_for_me/models/social_post_media.rb', line 24 optional :tags, -> { PostForMe::Internal::Type::ArrayOf[PostForMe::SocialPostMedia::Tag] }, nil?: true |
#thumbnail_timestamp_ms ⇒ Object?
Timestamp in milliseconds of frame to use as thumbnail for the media
30 |
# File 'lib/post_for_me/models/social_post_media.rb', line 30 optional :thumbnail_timestamp_ms, PostForMe::Internal::Type::Unknown, nil?: true |
#thumbnail_url ⇒ Object?
Public URL of the thumbnail for the media
36 |
# File 'lib/post_for_me/models/social_post_media.rb', line 36 optional :thumbnail_url, PostForMe::Internal::Type::Unknown, nil?: true |
#url ⇒ String
Public URL of the media
10 |
# File 'lib/post_for_me/models/social_post_media.rb', line 10 required :url, String |
Instance Method Details
#to_hash ⇒ {
31 |
# File 'sig/post_for_me/models/social_post_media.rbs', line 31
def to_hash: -> {
|