Class: PostForMe::Models::TiktokConfiguration
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PostForMe::Models::TiktokConfiguration
- Defined in:
- lib/post_for_me/models/tiktok_configuration.rb,
sig/post_for_me/models/tiktok_configuration.rbs
Instance Attribute Summary collapse
-
#allow_comment ⇒ Boolean?
Allow comments on TikTok.
-
#allow_duet ⇒ Boolean?
Allow duets on TikTok.
-
#allow_stitch ⇒ Boolean?
Allow stitch on TikTok.
-
#auto_add_music ⇒ Boolean?
Will automatically add music to photo posts.
-
#caption ⇒ Object?
Overrides the
captionfrom the post. -
#disclose_branded_content ⇒ Boolean?
Disclose branded content on TikTok.
-
#disclose_your_brand ⇒ Boolean?
Disclose your brand on TikTok.
-
#is_ai_generated ⇒ Boolean?
Flag content as AI generated on TikTok.
-
#is_draft ⇒ Boolean?
Will create a draft upload to TikTok, posting will need to be completed from within the app.
-
#media ⇒ Array<PostForMe::Models::SocialPostMedia>?
Overrides the
mediafrom the post. -
#privacy_status ⇒ String?
Sets the privacy status for TikTok (private, public).
-
#title ⇒ String?
Overrides the
titlefrom the post.
Instance Method Summary collapse
-
#initialize(allow_comment: nil, allow_duet: nil, allow_stitch: nil, auto_add_music: nil, caption: nil, disclose_branded_content: nil, disclose_your_brand: nil, is_ai_generated: nil, is_draft: nil, media: nil, privacy_status: nil, title: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see TiktokConfiguration for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(allow_comment: nil, allow_duet: nil, allow_stitch: nil, auto_add_music: nil, caption: nil, disclose_branded_content: nil, disclose_your_brand: nil, is_ai_generated: nil, is_draft: nil, media: nil, privacy_status: nil, title: nil) ⇒ Object
Some parameter documentations has been truncated, see PostForMe::Models::TiktokConfiguration for more details.
|
|
# File 'lib/post_for_me/models/tiktok_configuration.rb', line 79
|
Instance Attribute Details
#allow_comment ⇒ Boolean?
Allow comments on TikTok
10 |
# File 'lib/post_for_me/models/tiktok_configuration.rb', line 10 optional :allow_comment, PostForMe::Internal::Type::Boolean, nil?: true |
#allow_duet ⇒ Boolean?
Allow duets on TikTok
16 |
# File 'lib/post_for_me/models/tiktok_configuration.rb', line 16 optional :allow_duet, PostForMe::Internal::Type::Boolean, nil?: true |
#allow_stitch ⇒ Boolean?
Allow stitch on TikTok
22 |
# File 'lib/post_for_me/models/tiktok_configuration.rb', line 22 optional :allow_stitch, PostForMe::Internal::Type::Boolean, nil?: true |
#auto_add_music ⇒ Boolean?
Will automatically add music to photo posts
28 |
# File 'lib/post_for_me/models/tiktok_configuration.rb', line 28 optional :auto_add_music, PostForMe::Internal::Type::Boolean, nil?: true |
#caption ⇒ Object?
Overrides the caption from the post
34 |
# File 'lib/post_for_me/models/tiktok_configuration.rb', line 34 optional :caption, PostForMe::Internal::Type::Unknown, nil?: true |
#disclose_branded_content ⇒ Boolean?
Disclose branded content on TikTok
40 |
# File 'lib/post_for_me/models/tiktok_configuration.rb', line 40 optional :disclose_branded_content, PostForMe::Internal::Type::Boolean, nil?: true |
#disclose_your_brand ⇒ Boolean?
Disclose your brand on TikTok
46 |
# File 'lib/post_for_me/models/tiktok_configuration.rb', line 46 optional :disclose_your_brand, PostForMe::Internal::Type::Boolean, nil?: true |
#is_ai_generated ⇒ Boolean?
Flag content as AI generated on TikTok
52 |
# File 'lib/post_for_me/models/tiktok_configuration.rb', line 52 optional :is_ai_generated, PostForMe::Internal::Type::Boolean, nil?: true |
#is_draft ⇒ Boolean?
Will create a draft upload to TikTok, posting will need to be completed from within the app
59 |
# File 'lib/post_for_me/models/tiktok_configuration.rb', line 59 optional :is_draft, PostForMe::Internal::Type::Boolean, nil?: true |
#media ⇒ Array<PostForMe::Models::SocialPostMedia>?
Overrides the media from the post
65 |
# File 'lib/post_for_me/models/tiktok_configuration.rb', line 65 optional :media, -> { PostForMe::Internal::Type::ArrayOf[PostForMe::SocialPostMedia] }, nil?: true |
#privacy_status ⇒ String?
Sets the privacy status for TikTok (private, public)
71 |
# File 'lib/post_for_me/models/tiktok_configuration.rb', line 71 optional :privacy_status, String, nil?: true |
#title ⇒ String?
Overrides the title from the post
77 |
# File 'lib/post_for_me/models/tiktok_configuration.rb', line 77 optional :title, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
59 |
# File 'sig/post_for_me/models/tiktok_configuration.rbs', line 59
def to_hash: -> {
|