Class: PostForMe::Models::YoutubeConfigurationDto
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PostForMe::Models::YoutubeConfigurationDto
- Defined in:
- lib/post_for_me/models/youtube_configuration_dto.rb,
sig/post_for_me/models/youtube_configuration_dto.rbs
Defined Under Namespace
Modules: License, PrivacyStatus Classes: Localization
Instance Attribute Summary collapse
-
#caption ⇒ Object?
Overrides the
captionfrom the post. -
#category_id ⇒ String?
YouTube video category id (maps to snippet.categoryId; see YouTube Data API videoCategories.list).
-
#contains_synthetic_media ⇒ Boolean?
If true, marks the video as containing altered or synthetic content per YouTube's disclosure policy (maps to status.containsSyntheticMedia).
-
#default_language ⇒ String?
Default language of the video (BCP-47 language tag, e.g. "en").
-
#description ⇒ String?
Description for the YouTube video (maps to snippet.description).
-
#embeddable ⇒ Boolean?
If true the video can be embedded on other websites (maps to status.embeddable).
-
#license ⇒ Symbol, ...
The video's license (maps to status.license).
-
#localizations ⇒ Hash{Symbol=>PostForMe::Models::YoutubeConfigurationDto::Localization}?
Per-language localizations for the video title and description.
-
#made_for_kids ⇒ Boolean?
If true will notify YouTube the video is intended for kids (maps to status.selfDeclaredMadeForKids), defaults to false.
-
#media ⇒ Array<PostForMe::Models::SocialPostMedia>?
Overrides the
mediafrom the post. -
#privacy_status ⇒ Symbol, ...
Sets the privacy status of the video (maps to status.privacyStatus), will default to public.
-
#public_stats_viewable ⇒ Boolean?
If true, the extended video statistics are publicly viewable (maps to status.publicStatsViewable).
-
#publish_at ⇒ String?
ISO 8601 datetime at which the video should be published.
-
#recording_date ⇒ String?
ISO 8601 date (YYYY-MM-DD) or datetime when the video was recorded (maps to recordingDetails.recordingDate).
-
#tags ⇒ Array<String>?
YouTube video tags (maps to snippet.tags).
-
#title ⇒ String?
Overrides the
titlefrom the post (maps to snippet.title).
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(description: nil, title: nil) ⇒ Object
|
|
# File 'lib/post_for_me/models/youtube_configuration_dto.rb', line 165
|
Instance Attribute Details
#caption ⇒ Object?
Overrides the caption from the post
20 |
# File 'lib/post_for_me/models/youtube_configuration_dto.rb', line 20 optional :caption, PostForMe::Internal::Type::Unknown, nil?: true |
#category_id ⇒ String?
YouTube video category id (maps to snippet.categoryId; see YouTube Data API videoCategories.list)
27 |
# File 'lib/post_for_me/models/youtube_configuration_dto.rb', line 27 optional :category_id, String, nil?: true |
#contains_synthetic_media ⇒ Boolean?
If true, marks the video as containing altered or synthetic content per YouTube's disclosure policy (maps to status.containsSyntheticMedia). YouTube adds a "How this content was made" label to the description automatically.
35 |
# File 'lib/post_for_me/models/youtube_configuration_dto.rb', line 35 optional :contains_synthetic_media, PostForMe::Internal::Type::Boolean, nil?: true |
#default_language ⇒ String?
Default language of the video (BCP-47 language tag, e.g. "en"). Maps to snippet.defaultLanguage.
42 |
# File 'lib/post_for_me/models/youtube_configuration_dto.rb', line 42 optional :default_language, String, nil?: true |
#description ⇒ String?
Description for the YouTube video (maps to snippet.description). Falls back to the post caption when not provided.
49 |
# File 'lib/post_for_me/models/youtube_configuration_dto.rb', line 49 optional :description, String, nil?: true |
#embeddable ⇒ Boolean?
If true the video can be embedded on other websites (maps to status.embeddable). Defaults to true.
56 |
# File 'lib/post_for_me/models/youtube_configuration_dto.rb', line 56 optional :embeddable, PostForMe::Internal::Type::Boolean, nil?: true |
#license ⇒ Symbol, ...
The video's license (maps to status.license). "youtube" is the standard YouTube license; "creativeCommon" is Creative Commons.
63 |
# File 'lib/post_for_me/models/youtube_configuration_dto.rb', line 63 optional :license, enum: -> { PostForMe::YoutubeConfigurationDto::License }, nil?: true |
#localizations ⇒ Hash{Symbol=>PostForMe::Models::YoutubeConfigurationDto::Localization}?
Per-language localizations for the video title and description. Keys are BCP-47 language tags (e.g. "fr", "es"). Maps to localizations on the YouTube Data API videos resource.
12 13 14 |
# File 'lib/post_for_me/models/youtube_configuration_dto.rb', line 12 required :localizations, -> { PostForMe::Internal::Type::HashOf[PostForMe::YoutubeConfigurationDto::Localization] }, nil?: true |
#made_for_kids ⇒ Boolean?
If true will notify YouTube the video is intended for kids (maps to status.selfDeclaredMadeForKids), defaults to false
70 |
# File 'lib/post_for_me/models/youtube_configuration_dto.rb', line 70 optional :made_for_kids, PostForMe::Internal::Type::Boolean, nil?: true |
#media ⇒ Array<PostForMe::Models::SocialPostMedia>?
Overrides the media from the post
76 |
# File 'lib/post_for_me/models/youtube_configuration_dto.rb', line 76 optional :media, -> { PostForMe::Internal::Type::ArrayOf[PostForMe::SocialPostMedia] }, nil?: true |
#privacy_status ⇒ Symbol, ...
Sets the privacy status of the video (maps to status.privacyStatus), will default to public
83 |
# File 'lib/post_for_me/models/youtube_configuration_dto.rb', line 83 optional :privacy_status, enum: -> { PostForMe::YoutubeConfigurationDto::PrivacyStatus }, nil?: true |
#public_stats_viewable ⇒ Boolean?
If true, the extended video statistics are publicly viewable (maps to status.publicStatsViewable). Defaults to true.
90 |
# File 'lib/post_for_me/models/youtube_configuration_dto.rb', line 90 optional :public_stats_viewable, PostForMe::Internal::Type::Boolean, nil?: true |
#publish_at ⇒ String?
ISO 8601 datetime at which the video should be published. Only honoured when privacy_status is "private" (maps to status.publishAt).
97 |
# File 'lib/post_for_me/models/youtube_configuration_dto.rb', line 97 optional :publish_at, String, nil?: true |
#recording_date ⇒ String?
ISO 8601 date (YYYY-MM-DD) or datetime when the video was recorded (maps to recordingDetails.recordingDate).
104 |
# File 'lib/post_for_me/models/youtube_configuration_dto.rb', line 104 optional :recording_date, String, nil?: true |
#tags ⇒ Array<String>?
YouTube video tags (maps to snippet.tags)
110 |
# File 'lib/post_for_me/models/youtube_configuration_dto.rb', line 110 optional :tags, PostForMe::Internal::Type::ArrayOf[String], nil?: true |
#title ⇒ String?
Overrides the title from the post (maps to snippet.title)
116 |
# File 'lib/post_for_me/models/youtube_configuration_dto.rb', line 116 optional :title, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/post_for_me/models/youtube_configuration_dto.rb', line 180
|
Instance Method Details
#to_hash ⇒ {
75 |
# File 'sig/post_for_me/models/youtube_configuration_dto.rbs', line 75
def to_hash: -> {
|